<?php
/**
 * The template for displaying comments.
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package imate
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}

function imate_comment($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
	<li class="comment-item clearfix" id="comment-<?php echo esc_attr($comment->comment_ID) ?>">
		<?php if(get_avatar($comment, '300')) { ?>
			<div class="image"><div><?php echo get_avatar($comment, '300') ?></div></div>
		<?php } ?>
		<div class="area">
			<div class="top">
				<div class="name"><?php echo esc_html($comment->comment_author); ?></div>
				<div class="time"><i class="material-design-icon-history-clock-button"></i><span><?php echo mysql2date(get_option( 'time_format' ).', '.get_option( 'date_format' ), $comment->comment_date); ?></span></div>
				<a href="#" class="replytocom" data-id="<?php echo esc_html(get_comment_ID()) ?>"><i class="material-design-icon-reply-all-button"></i><span><?php echo esc_html_e( 'reply', 'imate' ); ?></span></a>
			</div>
			<div class="content">
				<?php echo wp_kses_post($comment->comment_content) ?>
			</div>
		</div>
	</li>
<?php
}
?>

<div id="comments" class="comments-area">

	<?php
	// You can start editing here -- including this comment!
	if ( have_comments() ) : ?>
		<div class="comment-items-wrap">
			<h5><?php echo esc_html__('Comments', 'imate') ?></h5>
			<ul class="comment-items">
				<?php wp_list_comments(array('callback' => 'imate_comment')); ?>
			</ul>
			<?php if(paginate_comments_links()) { ?>
			<div class="pagination">
				<?php echo paginate_comments_links(); ?>
			</div>
			<?php } ?>
		</div>
		<?php

	endif; // Check for have_comments().


	// If comments are closed and there are comments, let's leave a little note, shall we?
	if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) : ?>

		<p class="no-comments"><?php echo esc_html_e( 'comments are closed.', 'imate' ); ?></p>
	<?php
	endif;
	//we don't use this functions
	
	add_filter('comment_form_fields', 'imate_reorder_comment_fields' );
	function imate_reorder_comment_fields( $fields ){
		// die(print_r( $fields ));

		$new_fields = array(); 

		$myorder = array('author','email','url','comment');

		foreach( $myorder as $key ){
			$new_fields[ $key ] = $fields[ $key ];
			unset( $fields[ $key ] );
		}

		if( $fields )
			foreach( $fields as $key => $val )
				$new_fields[ $key ] = $val;

		return $new_fields;
	}

	$post_id = get_the_ID();
	?>

	<div id="commentform-area">
		<?php comment_form(array(
			'fields' => array(
				'author' => '<div class="col-xs-12 col-sm-6"><div class="input-row-s1"><input id="author" class="style1" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" placeholder="'. esc_attr__( 'Your Name','imate' ) .'" /></div></div>',
				'email'  => '<div class="col-xs-12 col-sm-6"><div class="input-row-s1"><input id="email" class="style1" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" placeholder="'. esc_attr__( 'Your E-mail','imate' ) .'" /></div></div>',
				'url'    => '',
			),
			'logged_in_as'         => '<div class="col-xs-12 logged-links"><p>' . sprintf( __( '<a href="%1$s" aria-label="Logged in as %2$s. Edit your profile.">Logged in as %2$s</a> <a href="%3$s" class="logout">Log out</a>','imate' ), get_edit_user_link(), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink( $post_id ) ) ) ) . '</p></div>',
			'class_form'           => 'comment-form row',
			'comment_field'        => '<div class="col-xs-12"><div class="input-row-s1"><textarea id="comment" class="style1" name="comment" rows="5" maxlength="65525" required="required" placeholder="'. esc_attr__( 'Your Comment','imate' ) .'"></textarea></div></div>',
			'label_submit'         => esc_html__( 'Send' ,'imate'),
			'submit_button'        => '<button name="%1$s" type="submit" id="%2$s" class="button-style2 button-with-icon"><span>%4$s</span><i class="fa fa-angle-right"></i></button>',
			'submit_field'         => '<div class="col-xs-12">%1$s %2$s</div>',
			'comment_notes_before' => '',
			'title_reply_before'   => '<h5><span>',
			'title_reply_after'    => '</span></h5>',
			'title_reply'          => esc_html__( 'Leave a Comment', 'imate' ),
		)) ?>
	</div>
</div><!-- #comments -->
