<?php
/**
 * imate functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package imate
 */

if ( ! function_exists( 'imate_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function imate_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on imate, use a find and replace
	 * to change 'imate' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'imate', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'navigation' => esc_html__( 'Primary navigation', 'imate' ),
		'side-navigation' => esc_html__( 'Side navigation', 'imate' ),
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	// Add theme support for WooCommerce.
	add_theme_support( 'woocommerce' );

	if ( ! isset( $content_width ) ) $content_width = 900;
}
endif;
add_action( 'after_setup_theme', 'imate_setup' ); 

/**
 * Remove Gutenberg
 */

add_filter('use_block_editor_for_post', '__return_false'); 

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function imate_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Sidebar', 'imate' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'imate' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="heading widget-title">',
		'after_title'   => '</h6>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer col 1', 'imate' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here.', 'imate' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="heading widget-title">',
		'after_title'   => '</h6>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer col 2', 'imate' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add widgets here.', 'imate' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="heading widget-title">',
		'after_title'   => '</h6>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer col 3', 'imate' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add widgets here.', 'imate' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="heading widget-title">',
		'after_title'   => '</h6>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer col 4', 'imate' ),
		'id'            => 'footer-4',
		'description'   => esc_html__( 'Add widgets here.', 'imate' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="heading widget-title">',
		'after_title'   => '</h6>',
	) );
}
add_action( 'widgets_init', 'imate_widgets_init' );

/*
Remove default woocommerce css
*/
add_filter( 'woocommerce_enqueue_styles', '__return_false' );

/**
 * Add Google fonts.
 */
function imate_fonts_url() {
	$font_url = '';
	if(!class_exists('WPBakeryShortCode')) {
	    $font_url = add_query_arg( 'family', 'Poppins:300,400,500,600,700,300italic,400italic,500italic,600italic,700italic%7CPoppins+Condensed', "//fonts.googleapis.com/css" );
	}
    return $font_url;
}

/**
 * Enqueue scripts and styles.
 */
function imate_scripts() {
	wp_enqueue_style( 'imate-style-default', get_stylesheet_uri() );

	wp_enqueue_style( 'imate-fonts', imate_fonts_url(), array(), '1.0.0' );

	if(function_exists('vc_icon_element_fonts_enqueue')) {
		vc_icon_element_fonts_enqueue( 'fontawesome' );
	} else {
		wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/css/font-awesome.min.css');
		wp_enqueue_style( 'imate-icons', get_template_directory_uri() . '/css/iconfont.css');
	}

	wp_enqueue_style( 'imate-frontend-grid', get_template_directory_uri() . '/css/frontend-grid.css');

	wp_enqueue_style( 'photoswipe', get_template_directory_uri() . '/css/photoswipe.css');

	wp_enqueue_style( 'photoswipe-default-skin', get_template_directory_uri() . '/css/default-skin.css');

	wp_enqueue_style( 'imate-circle-animations', get_template_directory_uri() . '/css/circle_animations.css');

	wp_enqueue_style( 'imate-style', get_template_directory_uri() . '/css/style.css');

	wp_enqueue_style( 'woocommerce-general', get_template_directory_uri() . '/css/woocommerce.css');

	wp_enqueue_style( 'woocommerce-layout', get_template_directory_uri() . '/css/woocommerce-layout.css');

	wp_enqueue_style( 'imate-mobile', get_template_directory_uri() . '/css/mobile.css');

	wp_enqueue_script( 'scrollbar', get_template_directory_uri() . '/js/jquery.scrollbar.min.js', array('jquery'), '', true );

	wp_enqueue_script( 'imate-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array('jquery'), '', true );

	wp_enqueue_script( 'imate-load-posts', get_template_directory_uri() . '/js/load-posts.js', array('jquery'), '', true );
	
	wp_enqueue_script( 'waypoints', get_template_directory_uri() . '/js/jquery.waypoints.min.js', array('jquery'), '', true );

	wp_enqueue_script( 'imagesloaded' );

	wp_enqueue_script( 'isotope', get_template_directory_uri() . '/js/isotope.pkgd.min.js', array('jquery'), '', true );

	wp_enqueue_script( 'photoswipe', get_template_directory_uri() . '/js/photoswipe.min.js', array('jquery'), '', true );

	wp_enqueue_script( 'photoswipe-ui-default', get_template_directory_uri() . '/js/photoswipe-ui-default.min.js', array('jquery'), '', true );

	wp_enqueue_script( 'imate-script', get_template_directory_uri() . '/js/script.js', array('jquery'), '', true );

	wp_enqueue_script( 'imate-plugins', get_template_directory_uri() . '/js/plugins.js', array('jquery'), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'imate_scripts', 100 );

function imate_add_editor_styles() {
	add_editor_style( get_template_directory_uri() . '/css/style.css' );
}
add_action( 'current_screen', 'imate_add_editor_styles' );

add_action( 'admin_enqueue_scripts', 'load_admin_styles', 1000 );
function load_admin_styles() {
	wp_enqueue_style( 'imate-base-admin-icons', get_template_directory_uri() . '/css/font-awesome.min.css');
	wp_enqueue_style( 'imate-backend', get_template_directory_uri() . '/css/admin.css', array(), '1.0', false );
	wp_enqueue_style( 'imate-shortcode-icons', get_template_directory_uri() . '/css/shortcode-icons.css', array(), '1.0', false );
}

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load TGM file.
 */
require get_template_directory() . '/tgm/tgm.php';

/**
 * Load Breadcrumbs.
 */
require get_template_directory() . '/inc/breadcrumbs.php';

/**
 * Load ACF.
 */
require get_template_directory() . '/inc/acf.php';
define( 'ACF_LITE', true );

/**
 * Load Theme Settings.
 */
require get_template_directory() . '/theme-settings/config.php';

/**
 * Site pagination.
 */
function imate_wp_corenavi($max_count = '') {
	global $wp_query;
	$pages = '';
	if(isset($max_count) && $max_count > 0) {
		$max = $max_count;
	} else {
		$max = $wp_query->max_num_pages;
	}

	if(get_query_var('paged') != 0) {
		$paged = get_query_var('paged');
	} else {
		$paged = get_query_var('page');
	}

	if (!$current = $paged) $current = 1;
	$a['base'] = str_replace(999999999, '%#%', get_pagenum_link(999999999));
	$a['total'] = $max;
	$a['current'] = $current;

	$a['mid_size'] = 5;
	$a['end_size'] = 1;
	$a['prev_text'] = '<';
	$a['next_text'] = '>';

	$html = "";
	if ($max > 1) $html .= '<div class="pagination col-xs-12">';
	$html .= paginate_links($a);
	if ($max > 1) $html .= '</div>';

	return $html;
}

add_action( 'admin_init', 'imate_hide_editor' );

function imate_hide_editor() {

        // Get the Post ID.
        if ( isset ( $_GET['post'] ) )
        $post_id = $_GET['post'];
        else if ( isset ( $_POST['post_ID'] ) )
        $post_id = $_POST['post_ID'];

    if( !isset ( $post_id ) || empty ( $post_id ) )
        return;

    // Get the name of the Page Template file.
    $template_file = get_post_meta($post_id, '_wp_page_template', true);

    if($template_file == 'page-coming-soon.php'){ // edit the template name
        remove_post_type_support('page', 'editor');
    }

}

add_filter('get_the_excerpt', 'shortcode_unautop');
add_filter('get_the_excerpt', 'do_shortcode');

add_action( 'vc_before_init', 'imate_vc_before_init_actions' );
 
function imate_vc_before_init_actions() {
    if( function_exists('vc_set_shortcodes_templates_dir') ){ 
        vc_set_shortcodes_templates_dir( get_template_directory() . '/vc-elements' );
    }
}

function imate_load_custom_fonts($init) {
	global $imate_theme;

	$array = '';

	if ( isset($imate_theme) && !empty($imate_theme) ) {
		if(isset($imate_theme['body-font-face']['font-family']) && !empty($imate_theme['body-font-face']['font-family'])) {
			$array .= $imate_theme['body-font-face']['font-family'].'='.$imate_theme['body-font-face']['font-family'].';';
		}
		if(isset($imate_theme['additional-font-face']['font-family']) && !empty($imate_theme['additional-font-face']['font-family'])) {
			$array .= $imate_theme['additional-font-face']['font-family'].'='.$imate_theme['additional-font-face']['font-family'].';';
		}
		if(isset($imate_theme['additional-font-face2']['font-family']) && !empty($imate_theme['additional-font-face2']['font-family'])) {
			$array .= $imate_theme['additional-font-face2']['font-family'].'='.$imate_theme['additional-font-face2']['font-family'].';';
		}
		if(isset($imate_theme['additional-font-face3']['font-family']) && !empty($imate_theme['additional-font-face3']['font-family'])) {
			$array .= $imate_theme['additional-font-face3']['font-family'].'='.$imate_theme['additional-font-face3']['font-family'].';';
		}
		if(isset($imate_theme['additional-font-face4']['font-family']) && !empty($imate_theme['additional-font-face4']['font-family'])) {
			$array .= $imate_theme['additional-font-face4']['font-family'].'='.$imate_theme['additional-font-face4']['font-family'].';';
		}
	}

    $font_formats = isset($init['font_formats']) ? $init['font_formats'] : 'Andale Mono=andale mono,times;Arial=arial,helvetica,sans-serif;Arial Black=arial black,avant garde;Book Antiqua=book antiqua,palatino;Comic Sans MS=comic sans ms,sans-serif;Courier New=courier new,courier;Georgia=georgia,palatino;Helvetica=helvetica;Impact=impact,chicago;Symbol=symbol;Tahoma=tahoma,arial,helvetica,sans-serif;Terminal=terminal,monaco;Times New Roman=times new roman,times;Trebuchet MS=trebuchet ms,geneva;Verdana=verdana,geneva;Webdings=webdings;Wingdings=wingdings,zapf dingbats;IBM Plex Sans Condensed=IBM Plex Sans Condensed, sans-serif';
	
	$init['fontsize_formats'] = "10px 11px 12px 13px 14px 15px 16px 17px 18px 19px 20px 21px 22px 23px 24px 25px 26px 27px 28px 29px 30px 32px 33px 34px 35px 36px 37px 38px 39px 40px";

	if(isset($array) && !empty($array)) {
		trim($array, ';');
		$custom_fonts = ';'.$array;

	    $init['font_formats'] = $font_formats . $custom_fonts;

	    return $init;
	} else {
		return false;
	}
}
add_filter('tiny_mce_before_init', 'imate_load_custom_fonts');

function imate_styles() {
	global $imate_theme;

	$style = array();

	$style['site_mode'] = 'light';
	$style['color_scheme'] = '';
	$style['color_scheme1'] = '';
	$style['color_scheme2'] = '';
	$style['color_scheme3'] = '';
	$style['color_scheme4'] = '';

	$style['header_style'] = 'logo-left';
	$style['header_color_mode'] = 'light';
	$style['header_color_mode_404'] = 'light';
	$style['header_color_mode_coming_soon'] = 'light';
	$style['header_container'] = 'container';
	$style['navigation_type'] = 'visible_menu';
	$style['css_classes'] = '';

	$style['logo_content'] = '<span class="l-b">'.get_bloginfo( 'name' ).'</span>';
	$style['logo_default_url'] = '';
	$style['logo_light_url'] = '';
	$style['logo_dark_url']  = '';
	$style['logo_dark_url_scheme2']  = '';

	$style['google_maps_api_key'] = '';

	$style['side_bar_button'] = 'yes';
	$style['search'] = 'yes';
	$style['cart'] = 'yes';
	$style['header_social_links'] = 'yes';

	$style['header_address'] = '';
	$style['header_mail'] = '';
	$style['header_phone'] = '';
	$style['header_work_time'] = '';
	$style['header_button'] = 'yes';
	$style['header_button_label'] = '';
	$style['header_button_url'] = '';

	$style['grid_lines'] = 'no';
	$style['header_space'] = 'yes';
	$style['footer'] = 'show';
	$style['footer_logo'] = 'show';
	$style['footer_social_buttons'] = 'show';
	$style['footer_scroll_up'] = 'show';
	$style['footer_col_1'] = '3';
	$style['footer_col_2'] = '3';
	$style['footer_col_3'] = '3';
	$style['footer_col_4'] = '3';
	$style['copyright_text']  = '';
	$style['sidebar_copyright_text']  = '';

	$style['social_target'] = '_self';
	$style['social_buttons_content'] = '';
	$style['sl_social_buttons_content'] = '';

	$style['404_bg'] = '';
	$style['404_page_content_align'] = 'tac';
	$style['404_sub_heading'] = esc_html__('Oooops...', 'imate');
	$style['404_heading'] = __('404 Error... You are on<br>a non existing page!', 'imate');

	$style['coming_soon_bg'] = '';
	$style['coming_soon_subscribe_code'] = '';
	$style['coming_soon_sub_heading'] = esc_html__('The website is under construction', 'imate');
	$style['coming_soon_heading'] = esc_html__('Coming Soon', 'imate');
	$style['coming_soon_text'] = esc_html__('Subscribe to the newsletter to stay in the latest news', 'imate');

	$style['project_header_color_mode'] = 'dark';
	$style['project_top_background'] = '';
	$style['project_top_heading'] = esc_html__('Gallery', 'imate');
	$style['project_style'] = 'slider';
	$style['project_image'] = 'full';
	$style['project_year'] = '';
	$style['project_location'] = '';
	$style['project_photography'] = '';
	$style['project_retouching'] = '';
	$style['project_count_cols'] = 'col2';
	$style['project_count_images'] = '';
	$style['project_portfolio_link'] = '';
	$style['project_before_image'] = '';
	$style['project_after_image'] = '';
	$style['project_sub_heading'] = '';
	$style['project_video_url'] = '';
	$style['project_feature_image'] = 'show';
	$style['project_date'] = 'show';
	$style['project_category'] = 'show';
	$style['project_like'] = 'show';
	$style['project_share'] = 'show';

	$style['blog_header_color_mode'] = 'dark';
	$style['blog_top_background'] = '';
	$style['blog_top_heading'] = esc_html__('Blog', 'imate');
	$style['blog_feature_image'] = 'show';
	$style['blog_date'] = 'show';
	$style['blog_category'] = 'show';
	$style['blog_like'] = 'show';
	$style['blog_share'] = 'show';

	$shop['shop_header_color_mode'] = 'dark';
	$shop['shop_top_background'] = '';

	$style['preloader_show'] = '1';
	$style['preloader_type'] = 'cube';
	$style['preloader_label'] = '';
	$style['preloader_img'] = '';
	$style['download_link'] = 'yes';
	$style['project_details'] = 'yes';

	$style['right_click_disable'] = '0';
	$style['right_click_disable_message'] = __('<p style="text-align: center"><strong><span>Content is protected. Right-click function is disabled.</span></strong></p>', 'imate');

	$style['protected_message'] = esc_html__( 'This content is password protected. To view it please enter your password below:', 'imate' );

	if ( isset($imate_theme) && !empty($imate_theme) ) {

		if(isset($imate_theme['header_social_links']) && $imate_theme['header_social_links'] == '1') {
			$style['header_social_links'] = 'yes';
		} else {
			$style['header_social_links'] = 'no';
		}

		if(isset($imate_theme['header_cart']) && $imate_theme['header_cart'] == '1') {
			$style['cart'] = 'yes';
		} else {
			$style['cart'] = 'no';
		}

		if(isset($imate_theme['header_search']) && $imate_theme['header_search'] == '1') {
			$style['search'] = 'yes';
		} else {
			$style['search'] = 'no';
		}

		if(isset($imate_theme['header_style']) && !empty($imate_theme['header_style'])) {
			$style['header_style'] = $imate_theme['header_style'];
		}

		if(isset($imate_theme['site_mode']) && !empty($imate_theme['site_mode'])) {
			$style['site_mode'] = $imate_theme['site_mode'];
		}

		if(isset($imate_theme['color_scheme']) && !empty($imate_theme['color_scheme'])) {
			$style['color_scheme'] = $imate_theme['color_scheme'];
		}

		if(isset($imate_theme['header_address']) && !empty($imate_theme['header_address'])) {
			$style['header_address'] = $imate_theme['header_address'];
		}

		if(isset($imate_theme['header_mail']) && !empty($imate_theme['header_mail'])) {
			$style['header_mail'] = $imate_theme['header_mail'];
		}

		if(isset($imate_theme['header_phone']) && !empty($imate_theme['header_phone'])) {
			$style['header_phone'] = $imate_theme['header_phone'];
		}

		if(isset($imate_theme['header_work_time']) && !empty($imate_theme['header_work_time'])) {
			$style['header_work_time'] = $imate_theme['header_work_time'];
		}

		if(isset($imate_theme['header_button_label']) && !empty($imate_theme['header_button_label'])) {
			$style['header_button_label'] = $imate_theme['header_button_label'];
		}

		if(isset($imate_theme['header_button_url']) && !empty($imate_theme['header_button_url'])) {
			$style['header_button_url'] = $imate_theme['header_button_url'];
		}

		if(isset($imate_theme['color_scheme1']) && !empty($imate_theme['color_scheme1'])) {
			$style['color_scheme1'] = $imate_theme['color_scheme1'];
		}

		if(isset($imate_theme['color_scheme2']) && !empty($imate_theme['color_scheme2'])) {
			$style['color_scheme2'] = $imate_theme['color_scheme2'];
		}

		if(isset($imate_theme['color_scheme3']) && !empty($imate_theme['color_scheme3'])) {
			$style['color_scheme3'] = $imate_theme['color_scheme3'];
		}

		if(isset($imate_theme['color_scheme4']) && !empty($imate_theme['color_scheme4'])) {
			$style['color_scheme4'] = $imate_theme['color_scheme4'];
		}

		if(isset($imate_theme['default_logo']['background-image']) && $imate_theme['default_logo']['background-image']) { 
			$style['logo_default_url'] = $imate_theme['default_logo']['background-image'];
		}
		if(isset($imate_theme['dark_logo']['background-image']) && $imate_theme['dark_logo']['background-image']) {
			$style['logo_dark_url'] = $imate_theme['dark_logo']['background-image'];
		}
 		if(isset($imate_theme['light_logo']['background-image']) && $imate_theme['light_logo']['background-image']) {
			$style['logo_light_url'] = $imate_theme['light_logo']['background-image'];
		}

		if(!empty($style['logo_light_url']) && !empty($style['logo_dark_url'])) {
			$style['logo_content'] = '<img class="light l-b" src="'.esc_url($style['logo_light_url']).'" alt="'.get_bloginfo( 'name' ).'"><img class="dark l-b" src="'.esc_url($style['logo_dark_url']).'" alt="'.get_bloginfo( 'name' ).'">';
		} elseif(!empty($style['logo_light_url']) || !empty($style['logo_dark_url'])) {
			if(!empty($style['logo_light_url'])) {
				$style['logo_content'] = '<img class="l-b" src="'.esc_url($style['logo_light_url']).'" alt="'.get_bloginfo( 'name' ).'">';
			}
			if(!empty($style['logo_dark_url'])) {
				$style['logo_content'] = '<img class="l-b" src="'.esc_url($style['logo_dark_url']).'" alt="'.get_bloginfo( 'name' ).'">';
			}
		} elseif(!empty($style['logo_default_url'])) {
			$style['logo_content'] = '<img class="l-b" src="'.esc_url($style['logo_default_url']).'" alt="'.get_bloginfo( 'name' ).'">';
		} elseif(isset($imate_theme['logo_text']) && $imate_theme['logo_text']) {
			$style['logo_content'] = '<span class="l-b">'.strip_tags($imate_theme['logo_text']).'<span>'.strip_tags($imate_theme['logo_text']).'</span></span>';
		} else {
			$style['logo_content'] = '<span class="l-b">'.get_bloginfo( 'name' ).'</span>';
		}

		if(isset($imate_theme['right_click_disable'])) {
			$style['right_click_disable'] = $imate_theme['right_click_disable'];
		}

		if(isset($imate_theme['right_click_disable_message']) && !empty($imate_theme['right_click_disable_message'])) {
			$style['right_click_disable_message'] = $imate_theme['right_click_disable_message'];
		}

		if(isset($imate_theme['protected_message']) && !empty($imate_theme['protected_message'])) {
			$style['protected_message'] = $imate_theme['protected_message'];
		}

		if(isset($imate_theme['google_maps_api_key']) && !empty($imate_theme['google_maps_api_key'])) {
			$style['google_maps_api_key'] = $imate_theme['google_maps_api_key'];
		}

		if(isset($imate_theme['navigation_type']) && !empty($imate_theme['navigation_type'])) {
			$style['navigation_type'] = $imate_theme['navigation_type'];
		}

		if(isset($imate_theme['header_container']) && !empty($imate_theme['header_container'])) {
			$style['header_container'] = $imate_theme['header_container'];
		}

		if(isset($imate_theme['header_color_mode']) && !empty($imate_theme['header_color_mode'])) {
			$style['header_color_mode'] = $imate_theme['header_color_mode'];
		}

		if(isset($imate_theme['header_color_mode_404']) && !empty($imate_theme['header_color_mode_404'])) {
			$style['header_color_mode_404'] = $imate_theme['header_color_mode_404'];
		}

		if(isset($imate_theme['header_color_mode_coming_soon']) && !empty($imate_theme['header_color_mode_coming_soon'])) {
			$style['header_color_mode_coming_soon'] = $imate_theme['header_color_mode_coming_soon'];
		}

		if(isset($imate_theme['copyright_text']) && !empty($imate_theme['copyright_text'])) {
			$style['copyright_text'] = $imate_theme['copyright_text'];
		}

		if(isset($imate_theme['sidebar_copyright_text']) && !empty($imate_theme['sidebar_copyright_text'])) {
			$style['sidebar_copyright_text'] = $imate_theme['sidebar_copyright_text'];
		}

		if(isset($imate_theme['footer']) && $imate_theme['footer']) {
			$style['footer'] = $imate_theme['footer'];
		}

		if(isset($imate_theme['footer_social_buttons']) && $imate_theme['footer_social_buttons']) {
			$style['footer_social_buttons'] = $imate_theme['footer_social_buttons'];
		}

		if(isset($imate_theme['footer_scroll_up']) && $imate_theme['footer_scroll_up']) {
			$style['footer_scroll_up'] = $imate_theme['footer_scroll_up'];
		}

		if(isset($imate_theme['footer_col_1'])) {
			$style['footer_col_1'] = $imate_theme['footer_col_1'];
		}

		if(isset($imate_theme['footer_col_2'])) {
			$style['footer_col_2'] = $imate_theme['footer_col_2'];
		}

		if(isset($imate_theme['footer_col_3'])) {
			$style['footer_col_3'] = $imate_theme['footer_col_3'];
		}

		if(isset($imate_theme['footer_col_4'])) {
			$style['footer_col_4'] = $imate_theme['footer_col_4'];
		}

		if(isset($imate_theme['404_bg']) && !empty($imate_theme['404_bg'])) {
			$style['404_bg'] = "background-image: url(".$imate_theme['404_bg']['background-image'].")";
		}

		if(isset($imate_theme['404_sub_heading'])) {
			$style['404_sub_heading'] = nl2br($imate_theme['404_sub_heading']);
		}

		if(isset($imate_theme['404_page_content_align']) && !empty($imate_theme['404_page_content_align'])) {
			$style['404_page_content_align'] = $imate_theme['404_page_content_align'];
		}

		if(isset($imate_theme['404_heading'])) {
			$style['404_heading'] = nl2br($imate_theme['404_heading']);
		}

		if(isset($imate_theme['404_text'])) {
			$style['404_text'] = nl2br($imate_theme['404_text']);
		}

		if(isset($imate_theme['coming_soon_bg']) && !empty($imate_theme['coming_soon_bg'])) {
			$style['coming_soon_bg'] = "background-image: url(".$imate_theme['coming_soon_bg']['background-image'].")";
		}

		if(isset($imate_theme['coming_soon_subscribe_code']) && $imate_theme['coming_soon_subscribe_code']) {
			$style['coming_soon_subscribe_code'] = $imate_theme['coming_soon_subscribe_code'];
		}

		if(isset($imate_theme['coming_soon_sub_heading'])) {
			$style['coming_soon_sub_heading'] = nl2br($imate_theme['coming_soon_sub_heading']);
		}

		if(isset($imate_theme['coming_soon_heading'])) {
			$style['coming_soon_heading'] = nl2br($imate_theme['coming_soon_heading']);
		}

		if(isset($imate_theme['coming_soon_text'])) {
			$style['coming_soon_text'] = nl2br($imate_theme['coming_soon_text']);
		}

		if(isset($imate_theme['project_style']) && $imate_theme['project_style']) {
			$style['project_style'] = $imate_theme['project_style'];
		}

		if(isset($imate_theme['project_count_cols']) && $imate_theme['project_count_cols']) {
			$style['project_count_cols'] = $imate_theme['project_count_cols'];
		}

		if(isset($imate_theme['project_count_images']) && $imate_theme['project_count_images']) {
			$style['project_count_images'] = $imate_theme['project_count_images'];
		}

		if(isset($imate_theme['project_portfolio_link']) && $imate_theme['project_portfolio_link']) {
			$style['project_portfolio_link'] = $imate_theme['project_portfolio_link'];
		}

		if(isset($imate_theme['project_image']) && $imate_theme['project_image']) {
			$style['project_image'] = $imate_theme['project_image'];
		}

		if(isset($imate_theme['preloader_show'])) {
			$style['preloader_show'] = $imate_theme['preloader_show'];
		}

		if(isset($imate_theme['preloader_type'])) {
			$style['preloader_type'] = $imate_theme['preloader_type'];
		}

		if(isset($imate_theme['preloader_label'])) {
			$style['preloader_label'] = $imate_theme['preloader_label'];
		}

		if(isset($imate_theme['blog_header_color_mode']) && (is_singular('post') || is_archive()) && $imate_theme['blog_header_color_mode'] != 'default') {
			$style['header_color_mode'] = $imate_theme['blog_header_color_mode'];
		}

		if(isset($imate_theme['project_header_color_mode']) && is_singular('fw-portfolio') && $imate_theme['project_header_color_mode'] != 'default') {
			$style['header_color_mode'] = $imate_theme['project_header_color_mode'];
		}

		if(isset($imate_theme['blog_feature_image'])) {
			$style['blog_feature_image'] = $imate_theme['blog_feature_image'];
		}

		if(isset($imate_theme['shop_header_color_mode']) && imate_is_woocommerce_page() && $imate_theme['shop_header_color_mode'] != 'default') {
			$style['header_color_mode'] = $imate_theme['shop_header_color_mode'];
		}

		if(isset($imate_theme['shop_top_background'])) {
			$style['shop_top_background'] = $imate_theme['shop_top_background']['background-image'];
		}

		if(isset($imate_theme['blog_top_background'])) {
			$style['blog_top_background'] = $imate_theme['blog_top_background']['background-image'];
		}

		if(isset($imate_theme['blog_top_heading'])) {
			$style['blog_top_heading'] = nl2br($imate_theme['blog_top_heading']);
		}

		if(isset($imate_theme['project_top_background'])) {
			$style['project_top_background'] = $imate_theme['project_top_background']['background-image'];
		}

		if(isset($imate_theme['project_top_heading'])) {
			$style['project_top_heading'] = nl2br($imate_theme['project_top_heading']);
		}

		if(isset($imate_theme['project_date'])) {
			$style['project_date'] = $imate_theme['project_date'];
		}

		if(isset($imate_theme['project_category'])) {
			$style['project_category'] = $imate_theme['project_category'];
		}

		if(isset($imate_theme['project_like'])) {
			$style['project_like'] = $imate_theme['project_like'];
		}

		if(isset($imate_theme['project_share'])) {
			$style['project_share'] = $imate_theme['project_share'];
		}

		if(isset($imate_theme['blog_date'])) {
			$style['blog_date'] = $imate_theme['blog_date'];
		}

		if(isset($imate_theme['blog_category'])) {
			$style['blog_category'] = $imate_theme['blog_category'];
		}

		if(isset($imate_theme['blog_like'])) {
			$style['blog_like'] = $imate_theme['blog_like'];
		}

		if(isset($imate_theme['blog_share'])) {
			$style['blog_share'] = $imate_theme['blog_share'];
		}
		
		if(isset($imate_theme['preloader_img']) && $imate_theme['preloader_img']) {
			$style['preloader_img'] = $imate_theme['preloader_img'];
		}
		
		if(isset($imate_theme['social_target']) && $imate_theme['social_target'] == '_blank') {
			$style['social_target'] = $imate_theme['social_target'];
		}

		if(isset($imate_theme['social_icon1']) && isset($imate_theme['social_link1']) && $imate_theme['social_icon1'] && $imate_theme['social_link1']) {
			$social_array = explode(',', $imate_theme['social_icon1']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($imate_theme['social_link1']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($imate_theme['social_icon2']) && isset($imate_theme['social_link2']) && $imate_theme['social_icon2'] && $imate_theme['social_link2']) {
			$social_array = explode(',', $imate_theme['social_icon2']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($imate_theme['social_link2']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($imate_theme['social_icon3']) && isset($imate_theme['social_link3']) && $imate_theme['social_icon3'] && $imate_theme['social_link3']) {
			$social_array = explode(',', $imate_theme['social_icon3']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($imate_theme['social_link3']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($imate_theme['social_icon4']) && isset($imate_theme['social_link4']) && $imate_theme['social_icon4'] && $imate_theme['social_link4']) {
			$social_array = explode(',', $imate_theme['social_icon4']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($imate_theme['social_link4']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($imate_theme['social_icon5']) && isset($imate_theme['social_link5']) && $imate_theme['social_icon5'] && $imate_theme['social_link5']) {
			$social_array = explode(',', $imate_theme['social_icon5']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($imate_theme['social_link5']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($imate_theme['social_icon6']) && isset($imate_theme['social_link6']) && $imate_theme['social_icon6'] && $imate_theme['social_link6']) {
			$social_array = explode(',', $imate_theme['social_icon6']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($imate_theme['social_link6']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($imate_theme['social_icon7']) && isset($imate_theme['social_link7']) && $imate_theme['social_icon7'] && $imate_theme['social_link7']) {
			$social_array = explode(',', $imate_theme['social_icon7']);
			$style['social_buttons_content'] .= '<a href="'.esc_url($imate_theme['social_link7']).'" target="'.esc_attr($style['social_target']).'"><i class="'.esc_attr($social_array[0]).'"></i> <span>'.esc_html($social_array[1]).'</span></a>';
		}

		if(isset($imate_theme['download-link']) && !empty($imate_theme['download-link'])) {
			$style['download_link'] = $imate_theme['download-link'];
		}

		if(isset($imate_theme['project-details']) && !empty($imate_theme['project-details'])) {
			$style['project_details'] = $imate_theme['project-details'];
		}
	}

	if(function_exists("get_field")) {

		if(get_field('header_container') == 'container') {
			$style['header_container'] = 'container';
		} elseif(get_field('header_container') == 'container-fluid') {
			$style['header_container'] = 'container-fluid';
		}

		if(get_field('header_color_mode') == 'light') {
			$style['header_color_mode'] = 'light';
		}

		if(get_field('header_color_mode') == 'dark') {
			$style['header_color_mode'] = 'dark';
		}

		if(get_field('site_hex')) {
			$style['site_hex'] = get_field('site_hex');
		}

		if(get_field('header_space')) {
			$style['header_space'] = get_field('header_space');
		}

		if(get_field('search') && get_field('search') != 'default') {
			$style['search'] = get_field('search');
		}

		if(get_field('cart') && get_field('cart') != 'default') {
			$style['cart'] = get_field('cart');
		}

		if(get_field('side_bar_button') && get_field('side_bar_button') != 'default') {
			$style['side_bar_button'] = get_field('side_bar_button');
		}

		if(get_field('header_social_links') && get_field('header_social_links') != 'default') {
			$style['header_social_links'] = get_field('header_social_links');
		}

		if(get_field('header_button') && get_field('header_button') != 'default') {
			$style['header_button'] = get_field('header_button');
		}

		if(get_field('grid_lines')) {
			$style['grid_lines'] = get_field('grid_lines');
		}

		if(get_field('navigation_type') && get_field('navigation_type') != 'default') {
			$style['navigation_type'] = get_field('navigation_type');
		}

		if(get_field('site_mode') && get_field('site_mode') != 'default') {
			$style['site_mode'] = get_field('site_mode');
		}

		if(get_field('header_style') && get_field('header_style') != 'default') {
			$style['header_style'] = get_field('header_style');
		}

		if(get_field('header_container') && get_field('header_container') != 'default') {
			$style['header_container'] = get_field('header_container');
		}

		if(get_field('footer_social_buttons') && get_field('footer_social_buttons') != 'default') {
			$style['footer_social_buttons'] = get_field('footer_social_buttons');
		}

		if(get_field('footer') && get_field('footer') != 'default') {
			$style['footer'] = get_field('footer');
		}

		if(get_field('project_style') && get_field('project_style') != 'default') {
			$style['project_style'] = get_field('project_style');
		}

		if(get_field('project_image') && get_field('project_image') != 'default') {
			$style['project_image'] = get_field('project_image');
		}

		if(get_field('project_client_name')) {
			$style['project_client_name'] = get_field('project_client_name');
		}
		
		if(get_field('project_year')) {
			$style['project_year'] = get_field('project_year');
		}

		if(get_field('project_location')) {
			$style['project_location'] = get_field('project_location');
		}

		if(get_field('project_photography')) {
			$style['project_photography'] = get_field('project_photography');
		}

		if(get_field('project_retouching')) {
			$style['project_retouching'] = get_field('project_retouching');
		}

		if(get_field('project_count_cols') && get_field('project_count_cols') != 'default') {
			$style['project_count_cols'] = get_field('project_count_cols');
		}

		if(get_field('project_count_images')) {
			$style['project_count_images'] = get_field('project_count_images');
		}

		if(get_field('project_before_image')) {
			$style['project_before_image'] = get_field('project_before_image');
		}

		if(get_field('project_after_image')) {
			$style['project_after_image'] = get_field('project_after_image');
		}

		if(get_field('project_sub_heading')) {
			$style['project_sub_heading'] = get_field('project_sub_heading');
		}

		if(get_field('project_video_url')) {
			$style['project_video_url'] = get_field('project_video_url');
		}
	}

	if($style['header_style'] == 'left_side' || is_404() || is_page_template('page-coming-soon.php')) {
		$style['header_space'] = 'no';
	}

	if(is_404()) {
		$style['css_classes'] .= ' '.$style['header_color_mode_404'];
	} else if(is_page_template('page-coming-soon.php')) {
		$style['css_classes'] .= ' '.$style['header_color_mode_coming_soon'];
		$style['navigation_type'] = 'disabled';
		$style['side_bar_button'] = 'no';
		$style['header_space'] = 'no';
		$style['cart'] = 'no';
		$style['search'] = 'no';
	} else if(is_search()) {
		$style['header_container'] = 'container';
		$style['css_classes'] = ' '.$style['header_color_mode'];
		$style['site_mode'] = $style['site_mode'];
		$style['header_space'] = 'yes';
	} else {
		$style['css_classes'] .= ' '.$style['header_color_mode'];
	}

	$page_thumb = get_post_thumbnail_id(get_the_ID());
	$page_image = '';

	if(!empty($page_thumb) && isset(wp_get_attachment_image_src($page_thumb, 'full')[0]) && (is_page_template('template-with-sidebar.php') || is_page())) {
		$page_image = wp_get_attachment_image_src($page_thumb, 'full')[0];
	}

	if(imate_is_woocommerce_page() && !empty($style['shop_top_background'])) {
		$style['header_space'] = 'no';
	}

	if(!empty($page_image) || ((is_singular('post') || is_archive()) && !empty($style['blog_top_background']) && !imate_is_woocommerce_page())) {
		$style['header_space'] = 'no';
	}

	if(is_singular('fw-portfolio') && !empty($style['project_top_background'])) {
		$style['header_space'] = 'no';
	}

	if(is_active_sidebar('page_sidebar') && $style['side_bar_button'] == 'yes' && ($style['header_style'] == 'logo-center' || $style['header_style'] == 'logo-left')) {
		$style['css_classes'] .= ' with-sidebar-button';
	}

	$style['css_classes'] .= ' header_'.$style['header_style'];

	if(get_post_type() == 'fw-portfolio' && $style['project_style'] == 'horizontal') {
		$style['header_container'] = 'container-fluid';
		$style['footer'] = 'hide';
	}

	if(get_post_type() == 'fw-portfolio' && ($style['project_style'] == 'grid' || $style['project_style'] == 'masonry')) {
		$style['grid_lines'] = 'yes';
	}

	if(get_post_type() == 'fw-portfolio' && $style['project_style'] == 'parallax') {
		$style['header_space'] = 'no';
		$style['header_style'] = 'left-side';
		$style['footer'] = 'hide';
	}

	if($style['header_space'] == 'yes' && !is_404() && !is_page_template('page-coming-soon.php')) {
		$style['css_classes'] .= ' header-space-on';
	}

	if(is_page_template('template-about.php')) {
		$style['footer'] = 'minified';
	}

	return $style;
}

add_filter( 'body_class', 'imate_custom_body_classes');
function imate_custom_body_classes( $classes ) {
	global $imate_theme;
	$site_mode = imate_styles()['site_mode'];

	$classes[] = 'header-type-'.imate_styles()['header_style'];
	$classes[] = 'header-nav-type-'.imate_styles()['navigation_type'];
	$classes[] = 'header-space-'.imate_styles()['header_space'];
	$classes[] = 'header-container-'.imate_styles()['header_container'];
    $classes[] = 'popup_download_'.imate_styles()['download_link'];
    $classes[] = 'project_details_'.imate_styles()['project_details'];
    $classes[] = 'grid_lines_'.imate_styles()['grid_lines'];
    $classes[] = 'site-'.$site_mode;

    if(imate_styles()['right_click_disable'] == '1') {
		$classes[] = 'right-click-disable';
	}

	if(is_404() || is_page_template('page-coming-soon.php')) {
		$classes[] = 'full-page-mode';
	}

	$thumb = get_post_thumbnail_id(get_the_ID());
	$image = '';

	if(!empty($thumb) && isset(wp_get_attachment_image_src($thumb, 'full')[0])) {
		$image = wp_get_attachment_image_src($thumb, 'full')[0];
	}

	if(imate_is_woocommerce_page() && !empty(imate_styles()['shop_top_background'])) {
		$image = imate_styles()['shop_top_background'];
	}

	if(!empty($image)) {
		$classes[] = 'header-decor-line';
	}
 
    return $classes;
}

add_action('wp_footer', 'imate_right_click_disable'); 
function imate_right_click_disable() {
	if(function_exists('imate_styles') && imate_styles()['right_click_disable'] == '1') {
	    echo '<div class="right-click-disable-message main-row"><div class="container"><div class="cell">'.wp_kses_post(imate_styles()['right_click_disable_message']).'</div></div></div>';
    } 
}

function fb_mce_before_init( $settings ) {

    $style_formats = array(
        array(
            'title' => 'thin',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '100',
            )
        ),
        array(
            'title' => 'extra-light',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '200',
            )
        ),
        array(
            'title' => 'light',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '300',
            )
        ),
        array(
            'title' => 'regular',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '400',
            )
        ),
        array(
            'title' => 'medium',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '500',
            )
        ),
        array(
            'title' => 'semi-bold',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '600',
            )
        ),
        array(
            'title' => 'bold',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '700',
            )
        ),
        array(
            'title' => 'extra-bold',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '800',
            )
        ),
        array(
            'title' => 'black',
            'inline' => 'span',
            'styles' => array(
                'fontWeight'    => '900',
            )
        ),
        array(
            'title' => 'UPPERCASE',
            'inline' => 'span',
            'styles' => array(
                'textTransform'    => 'uppercase',
            )
        ),
        array(
            'title' => 'Button style 1',
            'inline' => 'a',
            'classes' => 'button-style1',
			'wrapper' => true,
        ),
        array(
            'title' => 'Button style 2',
            'inline' => 'a',
            'classes' => 'button-style2',
			'wrapper' => true,
        )
    );

    $settings['style_formats'] = json_encode( $style_formats );

    return $settings;
}
add_filter( 'tiny_mce_before_init', 'fb_mce_before_init' );

if(function_exists('vc_add_param')) {
	vc_add_params( 'vc_custom_heading', array(
		array(
		    "type"        => "switch",
		    "heading"     => esc_html__( "Decor text on background", "imate" ),
		    "param_name"  => "decor_text_switch",
		    "value"       => "off",
		    "options"     => array(
		        "on" => array(
		            "on"    => "On",
		            "off"   => "Off",
		        ),
		    ),
		    "default_set" => false,
		),
		array(
		    "type"        => "textfield",
		    "heading"     => esc_html__( "Enter Decor text", "imate" ),
		    "param_name"  => "decor_text",
		    "dependency" => Array( "element" => "decor_text_switch", "value" => array( "on" ) ),
		),
		array(
		    "type"        => "textfield",
		    "heading"     => esc_html__( "Enter font size Decor text", "imate" ),
		    "param_name"  => "decor_font_size_text",
		    "dependency" => Array( "element" => "decor_text_switch", "value" => array( "on" ) ),
		),
		array(
		    "type"        => "colorpicker",
		    "heading"     => esc_html__( "Enter Decor text color", "imate" ),
		    "param_name"  => "decor_text_color",
		    "dependency" => Array( "element" => "decor_text_switch", "value" => array( "on" ) ),
		),
		array(
		    "type"        => "switch",
		    "class"       => "",
		    "heading"     => esc_html__( "Decor line", "imate" ),
		    "param_name"  => "decor_line",
		    "value"       => "off",
		    "options"     => array(
		        "on" => array(
		            "on"    => "On",
		            "off"   => "Off",
		        ),
		    ),
		    "default_set" => false,
		),
		array(
		    "type"        => "switch",
		    "class"       => "",
		    "heading"     => esc_html__( "Uppercase", "imate" ),
		    "param_name"  => "uppercase",
		    "value"       => "off",
		    "options"     => array(
		        "on" => array(
		            "on"    => "On",
		            "off"   => "Off",
		        ),
		    ),
		    "default_set" => false,
		),
	));

	vc_add_params("vc_row", array(
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Custom text color', 'imate' ),
			'param_name' => 'custom_text_color',
		),
		array(
			"type" => "dropdown",
			"class" => "",
			"heading" => esc_html__( "Background position", "imate" ),
			"param_name" => "background_position",
			"value" => array(
				esc_html__('Auto', 'imate') => '',
				"left center" => "left center",
				"left top" => "left top",
				"left bottom" => "left bottom",
				"center center" => "center center",
				"center top" => "center top",
				"center bottom" => "center bottom",
				"right center" => "right center",
				"right top" => "right top",
				"right bottom" => "right bottom"
			)
		),
        array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Gradient background', 'imate' ),
			'param_name' => 'show_background_gradient',
		),
		array(
			'type' => 'gradient',
			'heading' => esc_html__( 'Gradient', 'imate' ),
			'param_name' => 'background_gradient',
			'dependency' => array(
				'element' => 'show_background_gradient',
				'not_empty' => true,
			),
		),
        array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Color overlay', 'imate' ),
			'param_name' => 'color_overlay',
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Color overlay hex', 'imate' ),
			'param_name' => 'color_overlay_color',
			'dependency' => array(
				'element' => 'color_overlay',
				'not_empty' => true,
			),
		),
	));

	vc_add_params("vc_row_inner", array(
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Custom text color', 'imate' ),
			'param_name' => 'custom_text_color',
		),
		array(
			"type" => "dropdown",
			"class" => "",
			"heading" => esc_html__( "Background position", "imate" ),
			"param_name" => "background_position",
			"value" => array(
				esc_html__('Auto', 'imate') => '',
				"left center" => "left center",
				"left top" => "left top",
				"left bottom" => "left bottom",
				"center center" => "center center",
				"center top" => "center top",
				"center bottom" => "center bottom",
				"right center" => "right center",
				"right top" => "right top",
				"right bottom" => "right bottom"
			)
		),
        array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Gradient background', 'imate' ),
			'param_name' => 'show_background_gradient',
		),
		array(
			'type' => 'gradient',
			'heading' => esc_html__( 'Gradient', 'imate' ),
			'param_name' => 'background_gradient',
			'dependency' => array(
				'element' => 'show_background_gradient',
				'not_empty' => true,
			),
		),
        array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Color overlay', 'imate' ),
			'param_name' => 'color_overlay',
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Color overlay hex', 'imate' ),
			'param_name' => 'color_overlay_color',
			'dependency' => array(
				'element' => 'color_overlay',
				'not_empty' => true,
			),
		),
	));

	vc_add_params("vc_column", array(
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Custom text color', 'imate' ),
			'param_name' => 'custom_text_color',
		),
		array(
			"type" => "dropdown",
			"class" => "",
			"heading" => esc_html__( "Background position", "imate" ),
			"param_name" => "background_position",
			"value" => array(
				esc_html__('Auto', 'imate') => '',
				"left center" => "left center",
				"left top" => "left top",
				"left bottom" => "left bottom",
				"center center" => "center center",
				"center top" => "center top",
				"center bottom" => "center bottom",
				"right center" => "right center",
				"right top" => "right top",
				"right bottom" => "right bottom"
			)
		),
        array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Gradient background', 'imate' ),
			'param_name' => 'show_background_gradient',
		),
		array(
			'type' => 'gradient',
			'heading' => esc_html__( 'Gradient', 'imate' ),
			'param_name' => 'background_gradient',
			'dependency' => array(
				'element' => 'show_background_gradient',
				'not_empty' => true,
			),
		),
        array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Color overlay', 'imate' ),
			'param_name' => 'color_overlay',
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Color overlay hex', 'imate' ),
			'param_name' => 'color_overlay_color',
			'dependency' => array(
				'element' => 'color_overlay',
				'not_empty' => true,
			),
		),
	));

	vc_remove_param( "vc_icon", "background_color" );
	vc_remove_param( "vc_icon", "custom_color" );
	vc_remove_param( "vc_icon", "background_style" );
	vc_remove_param( "vc_icon", "background_color" );
	vc_remove_param( "vc_icon", "custom_background_color" );
	vc_remove_param( "vc_icon", "size" );
	vc_remove_param( "vc_icon", "align" );
	vc_remove_param( "vc_icon", "link" );
	vc_remove_param( "vc_icon", "el_id" );
	vc_remove_param( "vc_icon", "el_class" );
	vc_remove_param( "vc_icon", "css" );

	vc_add_params("vc_icon", array(
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Custom color', 'imate' ),
			'param_name' => 'custom_color',
			'description' => esc_html__( 'Select custom icon color.', 'imate' ),
			'dependency' => array(
				'element' => 'color',
				'value' => 'custom',
			),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Background shape', 'imate' ),
			'param_name' => 'background_style',
			'value' => array(
				esc_html__( 'None', 'imate' ) => '',
				esc_html__( 'Circle', 'imate' ) => 'rounded',
				esc_html__( 'Square', 'imate' ) => 'boxed',
				esc_html__( 'Rounded', 'imate' ) => 'rounded-less',
				esc_html__( 'Outline Circle', 'imate' ) => 'rounded-outline',
				esc_html__( 'Outline Square', 'imate' ) => 'boxed-outline',
				esc_html__( 'Outline Rounded', 'imate' ) => 'rounded-less-outline',
			),
			'description' => esc_html__( 'Select background shape and style for icon.', 'imate' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Background color', 'imate' ),
			'param_name' => 'background_color',
			'value' => array_merge( getVcShared( 'colors' ), array( esc_html__( 'Custom color', 'imate' ) => 'custom' ), array( esc_html__( 'Gradient', 'imate' ) => 'gradient' ) ),
			'std' => 'grey',
			'description' => esc_html__( 'Select background color for icon.', 'imate' ),
			'param_holder_class' => 'vc_colored-dropdown',
			'dependency' => array(
				'element' => 'background_style',
				'not_empty' => true,
			),
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Custom background color', 'imate' ),
			'param_name' => 'custom_background_color',
			'description' => esc_html__( 'Select custom icon background color.', 'imate' ),
			'dependency' => array(
				'element' => 'background_color',
				'value' => 'custom',
			),
		),
		array(
			'type' => 'gradient',
			'heading' => esc_html__( 'Custom background gradient', 'imate' ),
			'param_name' => 'custom_background_gradient',
			'dependency' => array(
				'element' => 'background_color',
				'value' => 'gradient',
			),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Size', 'imate' ),
			'param_name' => 'size',
			'value' => array_merge( getVcShared( 'sizes' ), array( 'Extra Large' => 'xl' ) ),
			'std' => 'md',
			'description' => esc_html__( 'Icon size.', 'imate' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Icon alignment', 'imate' ),
			'param_name' => 'align',
			'value' => array(
				__( 'Left', 'imate' ) => 'left',
				__( 'Right', 'imate' ) => 'right',
				__( 'Center', 'imate' ) => 'center',
			),
			'description' => esc_html__( 'Select icon alignment.', 'imate' ),
		),
		array(
			'type' => 'vc_link',
			'heading' => esc_html__( 'URL (Link)', 'imate' ),
			'param_name' => 'link',
			'description' => esc_html__( 'Add link to icon.', 'imate' ),
		),
		vc_map_add_css_animation(),
		array(
			'type' => 'el_id',
			'heading' => esc_html__( 'Element ID', 'imate' ),
			'param_name' => 'el_id',
			'description' => sprintf( __( 'Enter element ID (Note: make sure it is unique and valid according to <a href="%s" target="_blank">w3c specification</a>).', 'imate' ), 'http://www.w3schools.com/tags/att_global_id.asp' ),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Extra class name', 'imate' ),
			'param_name' => 'el_class',
			'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'imate' ),
		),
		array(
			'type' => 'css_editor',
			'heading' => esc_html__( 'CSS box', 'imate' ),
			'param_name' => 'css',
			'group' => esc_html__( 'Design Options', 'imate' ),
		),
	));

	vc_remove_param( "vc_tta_accordion", "no_fill" );
	vc_remove_param( "vc_tta_accordion", "spacing" );
	vc_remove_param( "vc_tta_accordion", "gap" );
	vc_remove_param( "vc_tta_accordion", "c_align" );
	vc_remove_param( "vc_tta_accordion", "autoplay" );
	vc_remove_param( "vc_tta_accordion", "collapsible_all" );
	vc_remove_param( "vc_tta_accordion", "c_icon" );
	vc_remove_param( "vc_tta_accordion", "c_position" );
	vc_remove_param( "vc_tta_accordion", "active_section" );
	vc_remove_param( "vc_tta_accordion", "el_id" );
	vc_remove_param( "vc_tta_accordion", "el_class" );
	vc_remove_param( "vc_tta_accordion", "css" );

	vc_add_params("vc_tta_accordion", array(
        array(
            "type" => "gradient",
            "base_gradient" => "#ff6884 0%,#620044 100%",
            "base_orientation" => "horizontal",
            "heading" => esc_html__("Gradient on active", "imate"),
            "param_name" => "active_gradient",
			'dependency' => array(
				'element' => 'style',
				'value' => 'classic',
			),
        ),
        array(
            "type" => "colorpicker",
            "heading" => esc_html__("Text color active block", "imate"),
            "param_name" => "active_color",
			'dependency' => array(
				'element' => 'style',
				'value' => 'classic',
			),
        ),
		array(
			'type' => 'checkbox',
			'param_name' => 'no_fill',
			'heading' => esc_html__( 'Do not fill content area?', 'imate' ),
			'description' => esc_html__( 'Do not fill content area with color.', 'imate' ),
		),
		array(
			'type' => 'dropdown',
			'param_name' => 'spacing',
			'value' => array(
				esc_html__( 'None', 'imate' ) => '',
				'1px' => '1',
				'2px' => '2',
				'3px' => '3',
				'4px' => '4',
				'5px' => '5',
				'10px' => '10',
				'15px' => '15',
				'20px' => '20',
				'25px' => '25',
				'30px' => '30',
				'35px' => '35',
			),
			'heading' => esc_html__( 'Spacing', 'imate' ),
			'description' => esc_html__( 'Select accordion spacing.', 'imate' ),
		),
		array(
			'type' => 'dropdown',
			'param_name' => 'gap',
			'value' => array(
				esc_html__( 'None', 'imate' ) => '',
				'1px' => '1',
				'2px' => '2',
				'3px' => '3',
				'4px' => '4',
				'5px' => '5',
				'10px' => '10',
				'15px' => '15',
				'20px' => '20',
				'25px' => '25',
				'30px' => '30',
				'35px' => '35',
			),
			'heading' => esc_html__( 'Gap', 'imate' ),
			'description' => esc_html__( 'Select accordion gap.', 'imate' ),
		),
		array(
			'type' => 'dropdown',
			'param_name' => 'c_align',
			'value' => array(
				esc_html__( 'Left', 'imate' ) => 'left',
				esc_html__( 'Right', 'imate' ) => 'right',
				esc_html__( 'Center', 'imate' ) => 'center',
			),
			'heading' => esc_html__( 'Alignment', 'imate' ),
			'description' => esc_html__( 'Select accordion section title alignment.', 'imate' ),
		),
		array(
			'type' => 'dropdown',
			'param_name' => 'autoplay',
			'value' => array(
				esc_html__( 'None', 'imate' ) => 'none',
				'1' => '1',
				'2' => '2',
				'3' => '3',
				'4' => '4',
				'5' => '5',
				'10' => '10',
				'20' => '20',
				'30' => '30',
				'40' => '40',
				'50' => '50',
				'60' => '60',
			),
			'std' => 'none',
			'heading' => esc_html__( 'Autoplay', 'imate' ),
			'description' => esc_html__( 'Select auto rotate for accordion in seconds (Note: disabled by default).', 'imate' ),
		),
		array(
			'type' => 'checkbox',
			'param_name' => 'collapsible_all',
			'heading' => esc_html__( 'Allow collapse all?', 'imate' ),
			'description' => esc_html__( 'Allow collapse all accordion sections.', 'imate' ),
		),
		// Control Icons
		array(
			'type' => 'dropdown',
			'param_name' => 'c_icon',
			'value' => array(
				esc_html__( 'None', 'imate' ) => '',
				esc_html__( 'Chevron', 'imate' ) => 'chevron',
				esc_html__( 'Plus', 'imate' ) => 'plus',
				esc_html__( 'Triangle', 'imate' ) => 'triangle',
			),
			'std' => 'plus',
			'heading' => esc_html__( 'Icon', 'imate' ),
			'description' => esc_html__( 'Select accordion navigation icon.', 'imate' ),
		),
		array(
			'type' => 'dropdown',
			'param_name' => 'c_position',
			'value' => array(
				esc_html__( 'Left', 'imate' ) => 'left',
				esc_html__( 'Right', 'imate' ) => 'right',
			),
			'dependency' => array(
				'element' => 'c_icon',
				'not_empty' => true,
			),
			'heading' => esc_html__( 'Position', 'imate' ),
			'description' => esc_html__( 'Select accordion navigation icon position.', 'imate' ),
		),
		// Control Icons END
		array(
			'type' => 'textfield',
			'param_name' => 'active_section',
			'heading' => esc_html__( 'Active section', 'imate' ),
			'value' => 1,
			'description' => esc_html__( 'Enter active section number (Note: to have all sections closed on initial load enter non-existing number).', 'imate' ),
		),
		vc_map_add_css_animation(),
		array(
			'type' => 'el_id',
			'heading' => esc_html__( 'Element ID', 'imate' ),
			'param_name' => 'el_id',
			'description' => sprintf( __( 'Enter element ID (Note: make sure it is unique and valid according to <a href="%s" target="_blank">w3c specification</a>).', 'imate' ), 'http://www.w3schools.com/tags/att_global_id.asp' ),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Extra class name', 'imate' ),
			'param_name' => 'el_class',
			'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'imate' ),
		),
		array(
			'type' => 'css_editor',
			'heading' => esc_html__( 'CSS box', 'imate' ),
			'param_name' => 'css',
			'group' => esc_html__( 'Design Options', 'imate' ),
		),
	));
}

add_action( 'vc_before_init', 'imate_vc_before_init' );

function imate_vc_before_init() {
    if( function_exists('vc_set_shortcodes_templates_dir') ){
        vc_set_shortcodes_templates_dir( get_template_directory() . '/vc_templates' );
    }
}

/**
 * The order of the blocks
 **/

add_action( 'vc_before_init', 'imate_vcSetAsTheme' );
function imate_vcSetAsTheme() {
	if(function_exists('vc_set_as_theme')) {
    	vc_set_as_theme();
	}
}

function imate_browser_body_class($classes) {
        global $is_lynx, $is_gecko, $is_IE, $is_edge, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;
        if($is_lynx) $classes[] = 'lynx';
        elseif($is_gecko) $classes[] = 'gecko';
        elseif($is_opera) $classes[] = 'opera';
        elseif($is_NS4) $classes[] = 'ns4';
        elseif($is_safari) $classes[] = 'safari';
        elseif($is_chrome) $classes[] = 'chrome';
        elseif($is_edge) $classes[] = 'edge';
        elseif($is_IE) {
                $classes[] = 'ie';
                if(preg_match('/MSIE ([0-9]+)([a-zA-Z0-9.]+)/', filter_input(INPUT_SERVER, 'HTTP_USER_AGENT'), $browser_version))
                $classes[] = 'ie'.$browser_version[1];
        } else $classes[] = 'unknown';
        if($is_iphone) $classes[] = 'iphone';
        if ( stristr( filter_input(INPUT_SERVER, 'HTTP_USER_AGENT'),"mac") ) {
                 $classes[] = 'osx';
           } elseif ( stristr( filter_input(INPUT_SERVER, 'HTTP_USER_AGENT'),"linux") ) {
                 $classes[] = 'linux';
           } elseif ( stristr( filter_input(INPUT_SERVER, 'HTTP_USER_AGENT'),"windows") ) {
                 $classes[] = 'windows';
           }
        return $classes;
}
add_filter('body_class','imate_browser_body_class');

function imate_phpinfo2array() {
    $entitiesToUtf8 = function($input) {
        // http://php.net/manual/en/function.html-entity-decode.php#104617
        return preg_replace_callback("/(&#[0-9]+;)/", function($m) { return mb_convert_encoding($m[1], "UTF-8", "HTML-ENTITIES"); }, $input);
    };
    $plainText = function($input) use ($entitiesToUtf8) {
        return trim(html_entity_decode($entitiesToUtf8(strip_tags($input))));
    };
    $titlePlainText = function($input) use ($plainText) {
        return '# '.$plainText($input);
    };
    
    ob_start();
    phpinfo(-1);
    
    $phpinfo = array('phpinfo' => array());

    // Strip everything after the <h1>Configuration</h1> tag (other h1's)
    if (!preg_match('#(.*<h1[^>]*>\s*Configuration.*)<h1#s', ob_get_clean(), $matches)) {
        return array();
    }
    
    $input = $matches[1];
    $matches = array();

    if(preg_match_all(
        '#(?:<h2.*?>(?:<a.*?>)?(.*?)(?:<\/a>)?<\/h2>)|'.
        '(?:<tr.*?><t[hd].*?>(.*?)\s*</t[hd]>(?:<t[hd].*?>(.*?)\s*</t[hd]>(?:<t[hd].*?>(.*?)\s*</t[hd]>)?)?</tr>)#s',
        $input, 
        $matches, 
        PREG_SET_ORDER
    )) {
        foreach ($matches as $match) {
            $fn = strpos($match[0], '<th') === false ? $plainText : $titlePlainText;
            if (strlen($match[1])) {
                $phpinfo[$match[1]] = array();
            } elseif (isset($match[3])) {
                $keys1 = array_keys($phpinfo);
                $phpinfo[end($keys1)][$fn($match[2])] = isset($match[4]) ? array($fn($match[3]), $fn($match[4])) : $fn($match[3]);
            } else {
                $keys1 = array_keys($phpinfo);
                $phpinfo[end($keys1)][] = $fn($match[2]);
            }

        }
    }
    
    return $phpinfo;
}

function imate_let_to_num( $size ) {
	$l    = substr( $size, -1 );
	$ret  = substr( $size, 0, -1 );
	$byte = 1024;

	switch ( strtoupper( $l ) ) {
		case 'P':
			$ret *= 1024;
		case 'T':
			$ret *= 1024;
		case 'G':
			$ret *= 1024;
		case 'M':
			$ret *= 1024;
		case 'K':
			$ret *= 1024;
	}
	return $ret;
}
remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);
add_action( 'woocommerce_before_shop_loop_item_title', 'imate_woocommerce_template_loop_product_thumbnail', 10);

/**
 * WooCommerce Loop Product Thumbs
 **/
if ( ! function_exists( 'imate_woocommerce_template_loop_product_thumbnail' ) ) {
	function imate_woocommerce_template_loop_product_thumbnail() {
		echo imate_woocommerce_get_product_thumbnail();
	} 
}

/**
 * WooCommerce Product Thumbnail
 **/
if ( ! function_exists( 'imate_woocommerce_get_product_thumbnail' ) ) {
	
	function imate_woocommerce_get_product_thumbnail( $size = 'shop_catalog', $placeholder_width = 0, $placeholder_height = 0  ) {
		global $post, $woocommerce,$product;
		if ( ! $placeholder_width )
			$placeholder_width = wc_get_image_size( 'shop_catalog' )['width'];
		if ( ! $placeholder_height )
			$placeholder_height = wc_get_image_size( 'shop_catalog' )['height'];

		$class = implode( ' ', array_filter( array(
                'button',
                'product_type_' . $product->get_type(),
                $product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
                $product->supports( 'ajax_add_to_cart' ) ? 'ajax_add_to_cart' : '',
        ) ) );

		$output = '<div class="image">';
		
		$output .= '<a href="'.get_the_permalink().'" class="img">';
		if ( has_post_thumbnail() ) {

			$output .= get_the_post_thumbnail( $post->ID, $size );
			if($attachment_ids = $product->get_gallery_image_ids() ) {
				if(isset($attachment_ids[1])){
					$output .= wp_get_attachment_image( $attachment_ids[1] , 'shop_catalog', '', array('class'=>'show') );
				}
			}

		} else {
			
			$output .= '<img src="'. woocommerce_placeholder_img_src() .'" alt="'.esc_attr__('Placeholder', 'imate').'" width="' . $placeholder_width . '" height="' . $placeholder_height . '" />';
			
		}

		$output .= '</a></div>';

		return $output;
	}
}

/**
 * WooCommerce Single Meta
 **/
//remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_single_price');
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 25 );

function imate_woocommerce_template_single_meta_remove_category(){    

	global $post, $product;

	?>
	<div class="product_meta">

	  <?php do_action( 'woocommerce_product_meta_start' ); ?>

	  <?php if ( wc_product_sku_enabled() && $product->get_sku() && ( $product->get_sku() || $product->is_type( 'variable' ) ) ) : ?>

	    <span class="sku_wrapper"><?php _e( 'SKU:', 'imate' ); ?> <span class="sku" itemprop="sku"><?php echo strip_tags(( $sku = $product->get_sku() ) ? $sku : __( '---', 'imate' )); ?></span></span>

	  <?php endif; ?>

	 
	  <?php do_action( 'woocommerce_product_meta_end' ); ?>

	</div>

<?php }

add_action( 'woocommerce_single_product_summary', 'imate_woocommerce_template_single_detail', 3 );

function imate_woocommerce_template_single_detail() {
	global $product;
	$categories = get_the_terms( $product->get_id(), 'product_cat' );
	$categories_names = '';
	foreach ($categories as $category) {
	    $categories_names .= $category->name.', ';
	    break;
	}
	$categories_names = trim($categories_names, ', ');
	
	if(function_exists('get_field') && (!empty(get_field('event_date', $product->get_id()) || !empty(get_field('event_location', $product->get_id()))))) { ?>
		<span class="details">
			<?php if(!empty(get_field('event_date', $product->get_id()))) {
				$date = mysql2date('M d', get_field('event_date', $product->get_id()));
			?>
				<span class="d"><i class="material-design-icon-history-clock-button"></i><span><?php echo strip_tags($date) ?></span></span>
			<?php } if(!empty(get_field('event_location', $product->get_id()))) { ?>
				<span class="d"><i class="material-design-icon-map-placeholder"></i><span><?php echo strip_tags(get_field('event_location', $product->get_id())) ?></span></span>
			<?php } ?>
		</span>
	<?php }
}

remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10 );
add_action( 'woocommerce_shop_loop_item_title', 'imate_woocommerce_template_loop_product_title', 15 );

function imate_woocommerce_template_loop_product_title() {
	global $product;
	$categories = get_the_terms( $product->get_id(), 'product_cat' );
	$categories_names = '';
	foreach ($categories as $category) {
	    $categories_names .= $category->name.', ';
	    break;
	}
	$categories_names = trim($categories_names, ', ');
	?>
	<h2 class="woocommerce-loop-product__title">
		<?php echo strip_tags($product->get_name()) ?>
	</h2>
	<?php if(function_exists('get_field') && (!empty(get_field('event_date', $product->get_id()) || !empty(get_field('event_location', $product->get_id()))))) { ?>
		<span class="details">
			<?php if(!empty(get_field('event_date', $product->get_id()))) {
				$date = mysql2date('M d', get_field('event_date', $product->get_id()));
			?>
				<span class="d"><i class="material-design-icon-history-clock-button"></i><span><?php echo strip_tags($date) ?></span></span>
			<?php } if(!empty(get_field('event_location', $product->get_id()))) { ?>
				<span class="d"><i class="material-design-icon-map-placeholder"></i><span><?php echo strip_tags(get_field('event_location', $product->get_id())) ?></span></span>
			<?php } ?>
		</span>
	<?php }
}


add_filter( 'woocommerce_output_related_products_args', 'imate_related_products_args' );
function imate_related_products_args( $args ) {
	$args['posts_per_page'] = 4; // 4 related products
	$args['columns'] = 4; // arranged in 2 columns
	return $args;
}


/**
 * The order of the blocks
 **/

add_filter('add_to_cart_fragments', 'woocommerce_header_add_to_cart_fragment');

function woocommerce_header_add_to_cart_fragment( $fragments ) {
	global $woocommerce;

	ob_start();
	?>
	<div class="header-minicart woocommerce header-minicart-imate">
		<?php $count = $woocommerce->cart->cart_contents_count;
		if($count == 0) { ?>
		<div class="hm-cunt"><i class="base-icons-shopping-cart"></i><span><?php echo esc_html($count) ?></span></div>
		<?php } else { ?>
		<a class="hm-cunt" href="<?php echo esc_url(wc_get_cart_url()) ?>"><i class="base-icons-shopping-cart"></i><span><?php echo esc_html($count) ?></span></a>
		<?php } ?>
		<div class="minicart-wrap">
			<?php woocommerce_mini_cart(); ?>
		</div>
	</div>
	<?php
	$fragments['.header-minicart-imate'] = ob_get_clean();

	return $fragments;
}

add_filter( 'jpeg_quality', 'imate_filter_theme_image_full_quality' );
add_filter( 'wp_editor_set_quality', 'imate_filter_theme_image_full_quality' );

function imate_filter_theme_image_full_quality( $quality ) {
    return 100;
}

add_filter( 'the_password_form', 'imate_custom_password_form' );
function imate_custom_password_form() {
    global $post;
    $label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
    $o = '<form class="protected-post-form" action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post"><div class="cell">'. wp_kses_post(imate_styles()['protected_message']) .'<div class="area"><input name="post_password" placeholder="'.esc_attr__('Type the password', 'imate').'" id="' . $label . '" type="password" /><button type="submit" name="Submit" class="button"><i class="base-icons-padlock"></i></button></div></div></form>';
    return $o;
}

function imate_get_fw_index($id = null) {
	if(empty($id)) {
		$id = get_the_ID();
	}

	$args = array(
        'posts_per_page'  => '-1',
        'post_type'       => 'fw-portfolio',
        'post_status'     => 'publish',
    );

    $porfolio_array = new WP_Query( $args );

    foreach($porfolio_array->posts as $key => $post) {
    	if($post->ID == $id) {
    		$index = $key;
    		break;
    	}
    }

    $index++;

    if($index <= 9) {
    	$index = '0'.$index;
    }

    return $index;
}

function imate_is_woocommerce_page() {
    if( function_exists ( "is_woocommerce" ) && is_woocommerce()){
        return true;
    }
    $woocommerce_keys = array ( "woocommerce_shop_page_id" ,
        "woocommerce_terms_page_id" ,
        "woocommerce_cart_page_id" ,
        "woocommerce_checkout_page_id" ,
        "woocommerce_pay_page_id" ,
        "woocommerce_thanks_page_id" ,
        "woocommerce_myaccount_page_id" ,
        "woocommerce_edit_address_page_id" ,
        "woocommerce_view_order_page_id" ,
        "woocommerce_change_password_page_id" ,
        "woocommerce_logout_page_id" ,
        "woocommerce_lost_password_page_id" ) ;

    foreach ( $woocommerce_keys as $wc_page_id ) {
        if ( get_the_ID () == get_option ( $wc_page_id , 0 ) ) {
            return true ;
        }
    }
    return false;
}