<?php

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    $opt_name = "imate_theme";
    $opt_name = apply_filters( 'imate_theme/opt_name', $opt_name );

    $theme = wp_get_theme();

    $args = array(
        'opt_name'             => $opt_name,
        'display_name'         => $theme->get( 'Name' ),
        'display_version'      => $theme->get( 'Version' ),
        'menu_type'            => 'menu',
        'allow_sub_menu'       => true,
        'menu_title'           => esc_html__( 'Theme Options', 'imate' ),
        'page_title'           => esc_html__( 'Theme Options', 'imate' ),
        'google_api_key'       => '',
        'google_update_weekly' => true,
        'async_typography'     => true,
        'admin_bar'            => true,
        'admin_bar_icon'       => 'dashicons-portfolio',
        'admin_bar_priority'   => 50,
        'global_variable'      => '',
        'dev_mode'             => false,
        'update_notice'        => true,
        'customizer'           => true,
        'page_priority'        => null,
        'page_parent'          => 'themes.php',
        'page_permissions'     => 'manage_options',
        'menu_icon'            => '',
        'last_tab'             => '',
        'page_icon'            => 'icon-themes',
        'page_slug'            => '',
        'save_defaults'        => true,
        'default_show'         => false,
        'default_mark'         => '',
        'show_import_export'   => true,
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        'output_tag'           => true,
        'database'             => '',
        'use_cdn'              => true,
        'show_options_object'  => false
    );

    Redux::setArgs( $opt_name, $args );

    // Memory use

    if(function_exists('memory_get_usage')) {
        $memory_get_usage = max( imate_let_to_num( WP_MEMORY_LIMIT ), imate_let_to_num( @ini_get( 'memory_limit' ) ) );
        if ( $memory_get_usage < 67108864 ) {
            /* Translators: %1$s: Memory limit, %2$s: Docs link. */
            $memory_get_usage = '<span class="error"><i class="fa fa-exclamation-circle"></i> ' . sprintf( esc_html__( '%1$s - We recommend setting memory to at least 64MB. See: %2$s', 'imate' ), esc_html( size_format( $memory_get_usage ) ), '<a href="https://codex.wordpress.org/Editing_wp-config.php#Increasing_memory_allocated_to_PHP" target="_blank">' . esc_html__( 'Increasing memory allocated to PHP', 'imate' ) . '</a>' ) . '</span>';
        } else {
            $memory_get_usage = '<span class="green">' . esc_html( size_format( $memory_get_usage ) ) . '</span>';
        }
    } else {
        $memory_get_usage = '-';
    }

    // Debug mode

    if(( defined( 'WP_DEBUG' ) && WP_DEBUG ) == 1) {
        $debug_mode = '<i class="fa fa-check green"></i>';
    } else {
        $debug_mode = '<i class="fa fa-times red"></i>';
    }

    // Language

    if(function_exists('get_locale')) {
        $language = get_locale();
    } else {
        $language = '-';
    }

    // php version
    if ( version_compare( phpversion(), '7.2', '>=' ) ) {
        $phpversion = '<span class="green">' . esc_html( phpversion() ) . '</span>';
    } else {
        $update_link = ' <a href="https://wordpress.org/support/upgrade-php/" target="_blank">' . esc_html__( 'How to update your PHP version', 'imate' ) . '</a>';
        $notice = '';
        if ( version_compare( phpversion(), '5.4', '<' ) ) {
            $notice = esc_html__( 'WooCommerce will run under this version of PHP, however, some features such as geolocation are not compatible. Support for this version will be dropped in the next major release. We recommend using PHP version 7.2 or above for greater performance and security.', 'imate' ) . $update_link;
        } elseif ( version_compare( phpversion(), '5.6', '<' ) ) {
            $notice = esc_html__( 'WooCommerce will run under this version of PHP, however, it has reached end of life. We recommend using PHP version 7.2 or above for greater performance and security.', 'imate' ) . $update_link;
        } elseif ( version_compare( phpversion(), '7.2', '<' ) ) {
            $notice = esc_html__( 'We recommend using PHP version 7.2 or above for greater performance and security.', 'imate' ) . $update_link;
        }

        $phpversion = '<span class="error"><i class="fa fa-exclamation-circle"></i> ' . esc_html( phpversion() ) . ' - ' . wp_kses_post( $notice ) . '</span>';
    }

    // max execution time

    if(ini_get( 'max_execution_time' ) < 700 && ini_get( 'max_execution_time' ) != 0 && ini_get( 'max_execution_time' ) != -1) {
        $max_execution_time = ini_get( 'max_execution_time' ).' - <i class="fa fa-times red"></i> '.esc_html__('We recommended 700 and more.', 'imate');
    } else {
        $max_execution_time = ini_get( 'max_execution_time' );
    }

    // post max size

    if(imate_let_to_num( ini_get( 'post_max_size' ) ) < 52428800) {
        $post_max_size = '<span class="error">'.size_format(imate_let_to_num( ini_get( 'post_max_size' ) )).' - <i class="fa fa-times red"></i> '.esc_html__('We recommended  50MB and more.', 'imate').'</span>';
    } else {
        $post_max_size = '<span class="green">'.size_format(imate_let_to_num( ini_get( 'post_max_size' ) )).'</span>';
    }

    // max upload size

    if(wp_max_upload_size() < 104857700) {
        $max_upload_size = '<span class="error">'.size_format(wp_max_upload_size()).' - <i class="fa fa-times red"></i> '.esc_html__('We recommended 100MB and more.', 'imate').'</span>';
    } else {
        $max_upload_size = '<span class="green">'.size_format(wp_max_upload_size()).'</span>';
    }

    $info_html = '
<table class="redux-info-table" cellspacing="0">
    <thead>
        <tr>
            <th colspan="3">'.esc_html__('WordPress Environment', 'imate').'</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td class="title">'.esc_html__('Home URL:', 'imate').'</td>
            <td class="help"><a href="#" title="'.esc_attr__('The URL of your site`s homepage.', 'imate').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags(home_url('/')).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('Site URL:', 'imate').'</td>
            <td class="help"><a href="#" title="'.esc_attr__('The root URL of your site.', 'imate').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags(get_option( 'siteurl' )).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('WP Version:', 'imate').'</td>
            <td class="help"><a href="#" title="'.esc_attr__('The version of WordPress installed on your site.', 'imate').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post(get_bloginfo( 'version' )).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('WP Memory Limit:', 'imate').'</td>
            <td class="help"><a href="#" title="'.esc_attr__('The maximum amount of memory (RAM) that your site can use at one time.', 'imate').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($memory_get_usage).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('WP Debug Mode:', 'imate').'</td>
            <td class="help"><a href="#" title="'.esc_attr__('Displays whether or not WordPress is in Debug Mode.', 'imate').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($debug_mode).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('Language:', 'imate').'</td>
            <td class="help"><a href="#" title="'.esc_attr__('The current language used by WordPress. Default = English', 'imate').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags($language).'</td>
        </tr>
    </tbody>
</table>

<table class="redux-info-table" cellspacing="0">
    <thead>
        <tr>
            <th colspan="3">'.esc_html__('Server Environment', 'imate').'</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td class="title">'.esc_html__('Server Info:', 'imate').'</td>
            <td class="help"><a href="#" title="'.esc_attr__('Information about the web server that is currently hosting your site.', 'imate').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags(filter_input(INPUT_SERVER, 'SERVER_SOFTWARE')).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('PHP Version:', 'imate').'</td>
            <td class="help"><a href="#" title="'.esc_attr__('The version of PHP installed on your hosting server.', 'imate').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($phpversion).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('PHP Post Max Size:', 'imate').'</td>
            <td class="help"><a href="#" title="'.esc_attr__('The largest file size that can be contained in one post.', 'imate').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($post_max_size).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('PHP Max Execution Time:', 'imate').'</td>
            <td class="help"><a href="#" title="'.esc_attr__('The amount of time (in seconds) that your site will spend on a single operation before timing out (to avoid server lockups)', 'imate').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($max_execution_time).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('Max Upload Size:', 'imate').'</td>
            <td class="help"><a href="#" title="'.esc_attr__('The largest filesize that can be uploaded to your WordPress installation.', 'imate').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.wp_kses_post($max_upload_size).'</td>
        </tr>
    </tbody>
</table>
<table class="redux-info-table" cellspacing="0">
    <thead>
        <tr>
            <th colspan="3">'.esc_html__('Theme', 'imate').'</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td class="title">'.esc_html__('Name:', 'imate').'</td>
            <td class="help"><a href="#" title="'.esc_attr__('The name of the current active theme.', 'imate').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags(wp_get_theme()->get('Name')).'</td>
        </tr>
        <tr>
            <td class="title">'.esc_html__('Version:', 'imate').'</td>
            <td class="help"><a href="#" title="'.esc_attr__('The installed version of the current active theme.', 'imate').'" class="tooltipster fa fa-info-circle"></a></td>
            <td class="value">'.strip_tags(wp_get_theme()->get('Version')).'</td>
        </tr>
    </tbody>
</table>
    ';


    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'General', 'imate' ),
        'id'               => 'general',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-home',
        'fields'     => array(
            array(
                'id'       => 'color_scheme',
                'type'     => 'color',
                'title'    => esc_html__('Site color', 'imate'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array(
                    'background-color' => '.hm-cunt span, .button-style1:before, .banner-area .banner-bottom .dots .dot-item.current:before, .play-button i, .work-step-item .num .decor:before, .categories-area .categories .item a:hover .image:before, .button-style2.color2, .preloader-folding-cube .preloader-cube:before, .banner .banner-form .button-style2, .price-list.type2 .price-list-item .button-style2, .wpb_text_column ul li:before, .site-content ul li:before, .woocommerce span.onsale, .woocommerce div.product form.cart .single_add_to_cart_button, .minicart-wrap .buttons a.checkout, .widget_shopping_cart_content a.checkout',
                    
                    'border-color' => '.navigation > ul > li > a span:after',

                    'background' => '.event-schedule-area .event-dates .current .ed-item .day-num:after, .filter-button-group.style2 button.active:after, .testimonials .owl-dots .owl-dot.active, .accordion-items .accordion-item .label span:before, .accordion-items .accordion-item .label span:after, .li-block:before',
                    
                    'color' => '.minicart-wrap .total > span, .widget_shopping_cart_content .total > span, .minicart-wrap .cart_list .mini_cart_item .quantity, .widget_shopping_cart_content .cart_list .mini_cart_item .quantity, .banner .cell .sub-h, .banner .cell .h span, .banner-social-buttons > div > i, .num-box-item .num-wrap, .num-box-item .wrap .num, .button-style2:hover, .work-step-item .link, .blog-item .readmore-link, .contact-row .heading span, .contact-row .icon, .navigation li:hover > a, .navigation li.current-menu-item > a, .navigation li.current-menu-ancestor > a, .navigation li.current_page_item > a, .navigation li.current-menu-ancestor > a, .banner .cell .event-detail, .num-box-item .icon, .event-schedule-item .detail, .team-carousel .team-item .h, .social-buttons a:hover i, .price-list-item .price-area .price, .timer-area .position, .banner .cell .text ul li:before, .button-style1.t2:before, .icon-box-item .icon, .woocommerce .products .product .price, .testimonials .testimonial-item .bottom:before, .pt-special-heading .heading span, .portfolio-slider-w-filter .item .link, .blog-detail, .blog-item .wrap .blog-detail, .site-content .blog-detail, .zilla-likes.active, .portfolio-item h6 .categ, .price-list-item .wrap .top, .blog-detail span, .banner-social-buttons a:hover, .banner-coming-soon .countdownHolder .name, .blog-item.type-quote .quote:before, .widget_about_me .sub-h, .s-sidebar .widget_archive ul li a:before, .s-sidebar .widget_pages ul li a:before, .s-sidebar .widget_nav_menu ul li a:before, .s-sidebar .widget_categories ul li a:before, .tagcloud .tag-cloud-link:hover, .post-bottom .share-button > i, .logged-links, .comment-items .comment-item .image:before, .comment-items .comment-item .top .time, .woocommerce div.product p.price, .woocommerce div.product span.price, .woocommerce div.product p.price ins, .woocommerce div.product span.price ins, .woocommerce table.shop_table td.product-price > span, .woocommerce table.shop_table td.product-subtotal > span, .woocommerce a.remove:hover, .woocommerce-cart .cart-collaterals .cart_totals tr td .woocommerce-Price-amount, .woocommerce .cart-collaterals table.shop_table.woocommerce-checkout-review-order-table td .amount, .woocommerce .cart-collaterals table.shop_table.woocommerce-checkout-review-order-table .order-total td .amount',
                    
                    'stroke' => ''
                ),
            ),
            array(
                'id'       => 'right_click_disable',
                'type'     => 'switch',
                'title'    => esc_html__('Right click disable', 'imate'),
                'default'  => false,
            ),
            array(
                'id'       => 'right_click_disable_message',
                'type'     => 'editor',
                'title'    => esc_html__('Right click Message', 'imate'),
                'default'  => __('<p style="text-align: center"><strong><span style="font-size: 18px">Content is protected. Right-click function is disabled.</span></strong></p>', 'imate'),
                'args'   => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5
                ),
                'required' => array('right_click_disable','=',1)
            ),
            array(
                'id'       => 'protected_message',
                'type'     => 'editor',
                'title'    => esc_html__('Protected Page Message', 'imate'),
                'default'  => esc_html__( 'This content is password protected. To view it please enter your password below:', 'imate' ),
                'args'   => array(
                    'teeny'            => false,
                    'textarea_rows'    => 5
                ),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Preloader', 'imate' ),
        'id'               => 'general_preloader',
        'customizer_width' => '450px',
        'icon'             => 'fa fa-spinner',
        'fields'     => array(
            array(
                'id'       => 'preloader_show',
                'type'     => 'switch', 
                'title'    => esc_html__('Preloader', 'imate'),
                'default'  => true,
            ),
            array(
                'id'       => 'preloader_type',
                'type'     => 'select', 
                'title'    => esc_html__('Preloader type', 'imate'),
                'options'  => array(
                    'cube' => esc_html__('Cube', 'imate'),
                    'custom_image' => esc_html__('Custom image', 'imate'),
                ),
                'default'  => 'cube',
                'required' => array('preloader_show','=',1)
            ),
            array(
                'id'       => 'preloader_bg_color',
                'type'     => 'color',
                'title'    => esc_html__('Preloader background color', 'imate'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('background' => '.preloader, .preloader-area, .preloader-type2, .site-dark .preloader-type2'),
                'required' => array('preloader_show','=',1)
            ),
            array(
                'id'       => 'preloader_color',
                'type'     => 'color',
                'title'    => esc_html__('Preloader color', 'imate'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('background' => '.preloader-folding-cube .preloader-cube:before, .preloader-type2, .site-dark .preloader-type2'),
                'required' => array('preloader_show','=',1)
            ),
            array( 
                'id'       => 'preloader_img',
                'type'     => 'background',
                'title'    => esc_html__('Prelaoder image', 'imate'),
                'desc'     => esc_html__('Choose a default logo image to display' ,'imate'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
                'required' => array('preloader_type','=','custom_image')
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Logo', 'imate' ),
        'id'               => 'header_logo',
        'customizer_width' => '450px',
        'icon'             => 'fa fa-flag',
        'fields'     => array(
            array(
                'id'       => 'logo_text',
                'type'     => 'text',
                'title'    => esc_html__('Logo text', 'imate'),
            ),
            array( 
                'id'       => 'default_logo',
                'type'     => 'background',
                'title'    => esc_html__('Logo Image - normal', 'imate'),
                'desc'     => esc_html__('Choose a default logo image to display' ,'imate'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array( 
                'id'       => 'light_logo',
                'type'     => 'background',
                'title'    => esc_html__('Logo Image - light', 'imate'),
                'desc'     => esc_html__('Choose a logo image to display for "Light" header skin' ,'imate'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array( 
                'id'       => 'dark_logo',
                'type'     => 'background',
                'title'    => esc_html__('Logo Image - Dark', 'imate'),
                'desc'     => esc_html__('Choose a logo image to display for "Dark" header skin' ,'imate'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array(
                'id'       => 'logo_size',
                'units'    => 'px',
                'type'     => 'dimensions',
                'units_extended' => 'false',
                'title'    => esc_html__('Logo max width', 'imate'),
                'output'      => array('.site-header .logo img, .side-header .logo img, .side-bar-area .logo img, .site-header .logo a, .side-header .logo a, .site-footer .logo a'),
                'height'   => true,
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Header style', 'imate' ),
        'id'               => 'header_style_area',
        'customizer_width' => '450px',
        'icon'             => 'fa fa-sliders',
        'fields'     => array(
            array(
                'id'       => 'header_container',
                'type'     => 'select',
                'title'    => esc_html__('Header container', 'imate'), 
                'options'  => array(
                    'container' => esc_html__('Center container', 'imate'),
                    'container-fluid' => esc_html__('Full witdh', 'imate'),
                ),
                'default'  => 'container',
            ),
            array(
                'id'       => 'header_color_mode',
                'type'     => 'select',
                'title'    => esc_html__('Header color mode', 'imate'), 
                'options'  => array(
                    'dark' => esc_html__('Dark', 'imate'),
                    'light' => esc_html__('Light', 'imate'),
                ),
                'default'  => 'light',
            ),
            array(
                'id'       => 'header_style',
                'type'     => 'select',
                'title'    => esc_html__('Header type', 'imate'), 
                'options'  => array(
                    'logo-left' => esc_html__('Logo left', 'imate'),
                    'logo-center' => esc_html__('Logo center', 'imate'),
                ),
                'default'  => 'logo-left',
            ),
            array(
                'id'       => 'header_cart',
                'type'     => 'switch', 
                'title'    => esc_html__('Cart', 'imate'),
                'default'  => true,
            ),
            array(
                'id'       => 'header_search',
                'type'     => 'switch', 
                'title'    => esc_html__('Search', 'imate'),
                'default'  => true,
            ),
            array(
                'id'       => 'header_bg_color_light',
                'type'     => 'color',
                'title'    => esc_html__('Header Background Color for Light', 'imate'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('background-color' => '.site-header.light:before'),
            ),
            array(
                'id'       => 'header_bg_color_dark',
                'type'     => 'color',
                'title'    => esc_html__('Header Background Color for Dark', 'imate'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('background-color' => '.site-header.dark:before'),
            ),
            array(
                'id'       => 'header_text_light_color',
                'type'     => 'color',
                'title'    => esc_html__('Header Text Color for Light', 'imate'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.site-header.light'),
            ),
            array(
                'id'       => 'header_text_dark_color',
                'type'     => 'color',
                'title'    => esc_html__('Header Text Color for Dark', 'imate'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.site-header.dark'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Navigation', 'imate' ),
        'id'               => 'header_navigation',
        'customizer_width' => '450px',
        'icon'             => 'fa fa-bars',
        'fields'     => array(
            array(
                'id'       => 'navigation_type',
                'type'     => 'select',
                'title'    => esc_html__('Navigation type', 'imate'), 
                'options'  => array(
                    'disabled' => esc_html__('Disabled', 'imate'),
                    'hidden_menu' => esc_html__('Hidden menu', 'imate'),
                    'visible_menu' => esc_html__('Visible menu', 'imate'),
                ),
                'default'  => 'visible_menu',
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Typography', 'imate' ),
        'id'               => 'typography',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-font',
        'fields'     => array(
            array(
                'id'          => 'body-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('Body', 'imate'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('body'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'  => false,
                'all_styles' => true,
                'default'     => array(
                    'color'       => '#0e1116', 
                    'font-style'  => '400', 
                    'font-family' => 'Poppins', 
                    'google'      => true,
                    'font-size'   => '16px',
                ),
            ),
            array(
                'id'          => 'h1-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H1', 'imate'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h1, .h1'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'all_styles'  => true,
                'subsets'     => false,
                'color'       => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Poppins', 
                    'google'      => true,
                    'font-size'   => '60px',
                ),
            ),
            array(
                'id'          => 'h2-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H2', 'imate'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h2, .h2'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'color'       => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Poppins', 
                    'google'      => true,
                    'font-size'   => '48px',
                ),
            ),
            array(
                'id'          => 'h3-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H3', 'imate'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h3, .h3'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'color'       => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Poppins', 
                    'google'      => true,
                    'font-size'   => '36px',
                ),
            ),
            array(
                'id'          => 'h4-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H4', 'imate'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h4, .h4'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'color'       => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Poppins', 
                    'google'      => true,
                    'font-size'   => '30px',
                ),
            ),
            array(
                'id'          => 'h5-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H5', 'imate'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h5, .h5'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'color'       => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Poppins', 
                    'google'      => true,
                    'font-size'   => '24px',
                ),
            ),
            array(
                'id'          => 'h6-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('H6', 'imate'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h6, .h6'),
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'color'       => false,
                'default'     => array(
                    'font-style'  => '700', 
                    'font-family' => 'Poppins', 
                    'google'      => true,
                    'font-size'   => '18px',
                ),
            ),
            array(
                'id'          => 'additional-font-face',
                'type'        => 'typography', 
                'title'       => esc_html__('Additional Font Face', 'imate'),
                'default'     => array(
                    'font-family' => 'Poppins Condensed', 
                    'google'      => true,
                ),
                'google'      => true, 
                'font-backup' => true,
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'font-weight' => false,
                'font-size'   => false,
                'font-style'  => false,
                'color'       => false,
                'all_styles'  => true,
            ),
            array(
                'id'          => 'additional-font-face2',
                'type'        => 'typography', 
                'title'       => esc_html__('Additional Font Face 2', 'imate'),
                'google'      => true, 
                'font-backup' => true,
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'font-weight' => false,
                'font-size'   => false,
                'font-style'  => false,
                'color'       => false,
                'all_styles'  => true,
            ),
            array(
                'id'          => 'additional-font-face3',
                'type'        => 'typography', 
                'title'       => esc_html__('Additional Font Face 3', 'imate'),
                'google'      => true, 
                'font-backup' => true,
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'font-weight' => false,
                'font-size'   => false,
                'font-style'  => false,
                'color'       => false,
                'all_styles'  => true,
            ),
            array(
                'id'          => 'additional-font-face4',
                'type'        => 'typography', 
                'title'       => esc_html__('Additional Font Face 4', 'imate'),
                'google'      => true, 
                'font-backup' => true,
                'units'       => 'px',
                'text-align'  => false,
                'line-height' => false,
                'subsets'     => false,
                'font-weight' => false,
                'font-size'   => false,
                'font-style'  => false,
                'color'       => false,
                'all_styles'  => true,
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Social buttons', 'imate' ),
        'id'               => 'social_buttons',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-twitter',
        'fields'     => array(
            array(
                'id'       => 'social_target',
                'type'     => 'select',
                'title'    => esc_html__('Open link in', 'imate'), 
                'options'  => array(
                    '_self' => esc_html__('Current Tab', 'imate'),
                    '_blank' => esc_html__('New Tab', 'imate'),
                ),
            ),
            array(
                'id'       => 'sl1',
                'type'     => 'label',
                'title'    => esc_html__('Social button 1', 'imate'),
            ),
            array(
                'id'       => 'social_icon1',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'imate'), 
                'options'  => array(
                    '' => esc_html__('---', 'imate'),
                    'fa fa-500px,500px' => esc_html__('500px', 'imate'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'imate'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'imate'),
                    'social-media-elements-behance,Behance' => esc_html__('Behance', 'imate'),
                    'social-media-elements-dribble,Dribble' => esc_html__('Dribble', 'imate'),
                    'social-media-elements-dropbox,Dropbox' => esc_html__('Dropbox', 'imate'),
                    'social-media-elements-facebook,Facebook' => esc_html__('Facebook', 'imate'),
                    'social-media-elements-flickr,Flickr' => esc_html__('Flickr', 'imate'),
                    'social-media-elements-foursquare,Foursquare' => esc_html__('Foursquare', 'imate'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'imate'),
                    'social-media-elements-google-plus,Google' => esc_html__('Google', 'imate'),
                    'social-media-elements-instagram,Instagram' => esc_html__('Instagram', 'imate'),
                    'social-media-elements-linkedin,LinkedIn' => esc_html__('LinkedIn', 'imate'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'imate'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'imate'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'imate'),
                    'social-media-elements-pinterest,Pinterest' => esc_html__('Pinterest', 'imate'),
                    'fa fa-reddit,Reddit' => esc_html__('Reddit', 'imate'),
                    'social-media-elements-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'imate'),
                    'social-media-elements-tumblr,Tumblr' => esc_html__('Tumblr', 'imate'),
                    'social-media-elements-twitter,Twitter' => esc_html__('Twitter', 'imate'),
                    'social-media-elements-vimeo,Vimeo' => esc_html__('Vimeo', 'imate'),
                    'social-media-elements-vk,VK' => esc_html__('VK', 'imate'),
                    'social-media-elements-yahoo,Yahoo' => esc_html__('Yahoo', 'imate'),
                    'social-media-elements-youtube,Youtube' => esc_html__('Youtube', 'imate'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link1',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'imate'),
            ),
            array(
                'id'       => 'sb2',
                'type'     => 'label',
                'title'    => esc_html__('Social button 2', 'imate'),
            ),
            array(
                'id'       => 'social_icon2',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'imate'), 
                'options'  => array(
                    '' => esc_html__('---', 'imate'),
                    'fa fa-500px,500px' => esc_html__('500px', 'imate'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'imate'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'imate'),
                    'social-media-elements-behance,Behance' => esc_html__('Behance', 'imate'),
                    'social-media-elements-dribble,Dribble' => esc_html__('Dribble', 'imate'),
                    'social-media-elements-dropbox,Dropbox' => esc_html__('Dropbox', 'imate'),
                    'social-media-elements-facebook,Facebook' => esc_html__('Facebook', 'imate'),
                    'social-media-elements-flickr,Flickr' => esc_html__('Flickr', 'imate'),
                    'social-media-elements-foursquare,Foursquare' => esc_html__('Foursquare', 'imate'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'imate'),
                    'social-media-elements-google-plus,Google' => esc_html__('Google', 'imate'),
                    'social-media-elements-instagram,Instagram' => esc_html__('Instagram', 'imate'),
                    'social-media-elements-linkedin,LinkedIn' => esc_html__('LinkedIn', 'imate'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'imate'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'imate'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'imate'),
                    'social-media-elements-pinterest,Pinterest' => esc_html__('Pinterest', 'imate'),
                    'fa fa-reddit,Reddit' => esc_html__('Reddit', 'imate'),
                    'social-media-elements-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'imate'),
                    'social-media-elements-tumblr,Tumblr' => esc_html__('Tumblr', 'imate'),
                    'social-media-elements-twitter,Twitter' => esc_html__('Twitter', 'imate'),
                    'social-media-elements-vimeo,Vimeo' => esc_html__('Vimeo', 'imate'),
                    'social-media-elements-vk,VK' => esc_html__('VK', 'imate'),
                    'social-media-elements-yahoo,Yahoo' => esc_html__('Yahoo', 'imate'),
                    'social-media-elements-youtube,Youtube' => esc_html__('Youtube', 'imate'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link2',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'imate'),
            ),
            array(
                'id'       => 'sb3',
                'type'     => 'label',
                'title'    => esc_html__('Social button 3', 'imate'),
            ),
            array(
                'id'       => 'social_icon3',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'imate'), 
                'options'  => array(
                    '' => esc_html__('---', 'imate'),
                    'fa fa-500px,500px' => esc_html__('500px', 'imate'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'imate'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'imate'),
                    'social-media-elements-behance,Behance' => esc_html__('Behance', 'imate'),
                    'social-media-elements-dribble,Dribble' => esc_html__('Dribble', 'imate'),
                    'social-media-elements-dropbox,Dropbox' => esc_html__('Dropbox', 'imate'),
                    'social-media-elements-facebook,Facebook' => esc_html__('Facebook', 'imate'),
                    'social-media-elements-flickr,Flickr' => esc_html__('Flickr', 'imate'),
                    'social-media-elements-foursquare,Foursquare' => esc_html__('Foursquare', 'imate'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'imate'),
                    'social-media-elements-google-plus,Google' => esc_html__('Google', 'imate'),
                    'social-media-elements-instagram,Instagram' => esc_html__('Instagram', 'imate'),
                    'social-media-elements-linkedin,LinkedIn' => esc_html__('LinkedIn', 'imate'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'imate'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'imate'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'imate'),
                    'social-media-elements-pinterest,Pinterest' => esc_html__('Pinterest', 'imate'),
                    'fa fa-reddit,Reddit' => esc_html__('Reddit', 'imate'),
                    'social-media-elements-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'imate'),
                    'social-media-elements-tumblr,Tumblr' => esc_html__('Tumblr', 'imate'),
                    'social-media-elements-twitter,Twitter' => esc_html__('Twitter', 'imate'),
                    'social-media-elements-vimeo,Vimeo' => esc_html__('Vimeo', 'imate'),
                    'social-media-elements-vk,VK' => esc_html__('VK', 'imate'),
                    'social-media-elements-yahoo,Yahoo' => esc_html__('Yahoo', 'imate'),
                    'social-media-elements-youtube,Youtube' => esc_html__('Youtube', 'imate'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link3',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'imate'),
            ),
            array(
                'id'       => 'sb4',
                'type'     => 'label',
                'title'    => esc_html__('Social button 4', 'imate'),
            ),
            array(
                'id'       => 'social_icon4',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'imate'), 
                'options'  => array(
                    '' => esc_html__('---', 'imate'),
                    'fa fa-500px,500px' => esc_html__('500px', 'imate'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'imate'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'imate'),
                    'social-media-elements-behance,Behance' => esc_html__('Behance', 'imate'),
                    'social-media-elements-dribble,Dribble' => esc_html__('Dribble', 'imate'),
                    'social-media-elements-dropbox,Dropbox' => esc_html__('Dropbox', 'imate'),
                    'social-media-elements-facebook,Facebook' => esc_html__('Facebook', 'imate'),
                    'social-media-elements-flickr,Flickr' => esc_html__('Flickr', 'imate'),
                    'social-media-elements-foursquare,Foursquare' => esc_html__('Foursquare', 'imate'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'imate'),
                    'social-media-elements-google-plus,Google' => esc_html__('Google', 'imate'),
                    'social-media-elements-instagram,Instagram' => esc_html__('Instagram', 'imate'),
                    'social-media-elements-linkedin,LinkedIn' => esc_html__('LinkedIn', 'imate'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'imate'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'imate'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'imate'),
                    'social-media-elements-pinterest,Pinterest' => esc_html__('Pinterest', 'imate'),
                    'fa fa-reddit,Reddit' => esc_html__('Reddit', 'imate'),
                    'social-media-elements-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'imate'),
                    'social-media-elements-tumblr,Tumblr' => esc_html__('Tumblr', 'imate'),
                    'social-media-elements-twitter,Twitter' => esc_html__('Twitter', 'imate'),
                    'social-media-elements-vimeo,Vimeo' => esc_html__('Vimeo', 'imate'),
                    'social-media-elements-vk,VK' => esc_html__('VK', 'imate'),
                    'social-media-elements-yahoo,Yahoo' => esc_html__('Yahoo', 'imate'),
                    'social-media-elements-youtube,Youtube' => esc_html__('Youtube', 'imate'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link4',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'imate'),
            ),
            array(
                'id'       => 'sb5',
                'type'     => 'label',
                'title'    => esc_html__('Social button 5', 'imate'),
            ),
            array(
                'id'       => 'social_icon5',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'imate'), 
                'options'  => array(
                    '' => esc_html__('---', 'imate'),
                    'fa fa-500px,500px' => esc_html__('500px', 'imate'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'imate'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'imate'),
                    'social-media-elements-behance,Behance' => esc_html__('Behance', 'imate'),
                    'social-media-elements-dribble,Dribble' => esc_html__('Dribble', 'imate'),
                    'social-media-elements-dropbox,Dropbox' => esc_html__('Dropbox', 'imate'),
                    'social-media-elements-facebook,Facebook' => esc_html__('Facebook', 'imate'),
                    'social-media-elements-flickr,Flickr' => esc_html__('Flickr', 'imate'),
                    'social-media-elements-foursquare,Foursquare' => esc_html__('Foursquare', 'imate'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'imate'),
                    'social-media-elements-google-plus,Google' => esc_html__('Google', 'imate'),
                    'social-media-elements-instagram,Instagram' => esc_html__('Instagram', 'imate'),
                    'social-media-elements-linkedin,LinkedIn' => esc_html__('LinkedIn', 'imate'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'imate'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'imate'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'imate'),
                    'social-media-elements-pinterest,Pinterest' => esc_html__('Pinterest', 'imate'),
                    'fa fa-reddit,Reddit' => esc_html__('Reddit', 'imate'),
                    'social-media-elements-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'imate'),
                    'social-media-elements-tumblr,Tumblr' => esc_html__('Tumblr', 'imate'),
                    'social-media-elements-twitter,Twitter' => esc_html__('Twitter', 'imate'),
                    'social-media-elements-vimeo,Vimeo' => esc_html__('Vimeo', 'imate'),
                    'social-media-elements-vk,VK' => esc_html__('VK', 'imate'),
                    'social-media-elements-yahoo,Yahoo' => esc_html__('Yahoo', 'imate'),
                    'social-media-elements-youtube,Youtube' => esc_html__('Youtube', 'imate'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link5',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'imate'),
            ),
            array(
                'id'       => 'sb6',
                'type'     => 'label',
                'title'    => esc_html__('Social button 6', 'imate'),
            ),
            array(
                'id'       => 'social_icon6',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'imate'), 
                'options'  => array(
                    '' => esc_html__('---', 'imate'),
                    'fa fa-500px,500px' => esc_html__('500px', 'imate'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'imate'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'imate'),
                    'social-media-elements-behance,Behance' => esc_html__('Behance', 'imate'),
                    'social-media-elements-dribble,Dribble' => esc_html__('Dribble', 'imate'),
                    'social-media-elements-dropbox,Dropbox' => esc_html__('Dropbox', 'imate'),
                    'social-media-elements-facebook,Facebook' => esc_html__('Facebook', 'imate'),
                    'social-media-elements-flickr,Flickr' => esc_html__('Flickr', 'imate'),
                    'social-media-elements-foursquare,Foursquare' => esc_html__('Foursquare', 'imate'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'imate'),
                    'social-media-elements-google-plus,Google' => esc_html__('Google', 'imate'),
                    'social-media-elements-instagram,Instagram' => esc_html__('Instagram', 'imate'),
                    'social-media-elements-linkedin,LinkedIn' => esc_html__('LinkedIn', 'imate'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'imate'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'imate'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'imate'),
                    'social-media-elements-pinterest,Pinterest' => esc_html__('Pinterest', 'imate'),
                    'fa fa-reddit,Reddit' => esc_html__('Reddit', 'imate'),
                    'social-media-elements-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'imate'),
                    'social-media-elements-tumblr,Tumblr' => esc_html__('Tumblr', 'imate'),
                    'social-media-elements-twitter,Twitter' => esc_html__('Twitter', 'imate'),
                    'social-media-elements-vimeo,Vimeo' => esc_html__('Vimeo', 'imate'),
                    'social-media-elements-vk,VK' => esc_html__('VK', 'imate'),
                    'social-media-elements-yahoo,Yahoo' => esc_html__('Yahoo', 'imate'),
                    'social-media-elements-youtube,Youtube' => esc_html__('Youtube', 'imate'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link6',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'imate'),
            ),
            array(
                'id'       => 'sb7',
                'type'     => 'label',
                'title'    => esc_html__('Social button 7', 'imate'),
            ),
            array(
                'id'       => 'social_icon7',
                'type'     => 'select',
                'title'    => esc_html__('Social icon', 'imate'), 
                'options'  => array(
                    '' => esc_html__('---', 'imate'),
                    'fa fa-500px,500px' => esc_html__('500px', 'imate'),
                    'fa fa-adn,App.net' => esc_html__('App.net', 'imate'),
                    'fa fa-bitbucket,Bitbucket' => esc_html__('Bitbucket', 'imate'),
                    'social-media-elements-behance,Behance' => esc_html__('Behance', 'imate'),
                    'social-media-elements-dribble,Dribble' => esc_html__('Dribble', 'imate'),
                    'social-media-elements-dropbox,Dropbox' => esc_html__('Dropbox', 'imate'),
                    'social-media-elements-facebook,Facebook' => esc_html__('Facebook', 'imate'),
                    'social-media-elements-flickr,Flickr' => esc_html__('Flickr', 'imate'),
                    'social-media-elements-foursquare,Foursquare' => esc_html__('Foursquare', 'imate'),
                    'fa fa-github,GitHub' => esc_html__('GitHub', 'imate'),
                    'social-media-elements-google-plus,Google' => esc_html__('Google', 'imate'),
                    'social-media-elements-instagram,Instagram' => esc_html__('Instagram', 'imate'),
                    'social-media-elements-linkedin,LinkedIn' => esc_html__('LinkedIn', 'imate'),
                    'fa fa-windows,Windows' => esc_html__('Windows', 'imate'),
                    'fa fa-odnoklassniki,Odnoklassniki' => esc_html__('Odnoklassniki', 'imate'),
                    'fa fa-openid,OpenID' => esc_html__('OpenID', 'imate'),
                    'social-media-elements-pinterest,Pinterest' => esc_html__('Pinterest', 'imate'),
                    'fa fa-reddit,Reddit' => esc_html__('Reddit', 'imate'),
                    'social-media-elements-soundcloud,SoundCloud' => esc_html__('SoundCloud', 'imate'),
                    'social-media-elements-tumblr,Tumblr' => esc_html__('Tumblr', 'imate'),
                    'social-media-elements-twitter,Twitter' => esc_html__('Twitter', 'imate'),
                    'social-media-elements-vimeo,Vimeo' => esc_html__('Vimeo', 'imate'),
                    'social-media-elements-vk,VK' => esc_html__('VK', 'imate'),
                    'social-media-elements-yahoo,Yahoo' => esc_html__('Yahoo', 'imate'),
                    'social-media-elements-youtube,Youtube' => esc_html__('Youtube', 'imate'),
                ),
                'default'  => '',
            ),
            array(
                'id'       => 'social_link7',
                'type'     => 'text',
                'title'    => esc_html__('Link', 'imate'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Footer', 'imate' ),
        'id'               => 'footer_area',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-th-list',
        'fields'     => array(
            array(
                'id'       => 'footer',
                'type'     => 'select',
                'title'    => esc_html__('Footer', 'imate'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'imate'),
                    'hide' => esc_html__('Hide', 'imate'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'footer_logo_size',
                'units'    => 'px',
                'type'     => 'dimensions',
                'units_extended' => 'false',
                'title'    => esc_html__('Logo max width', 'imate'),
                'output'      => array('.site-footer .logo img'),
                'height'   => false,
                'default'  => array(
                    'Width'   => '46'
                ),
            ),
            array(
                'id'       => 'footer_bg_color',
                'type'     => 'color',
                'title'    => esc_html__('Footer Background Color', 'imate'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('background-color' => '.site-footer'),
            ),
            array(
                'id'       => 'footer_text_color',
                'type'     => 'color',
                'title'    => esc_html__('Footer Text Color', 'imate'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.site-footer'),
            ),
            array(
                'id'       => 'copyright_text',
                'type'     => 'text',
                'title'    => esc_html__('Copyright text', 'imate'),
            ),
            array(
                'id'       => 'footer_col_1',
                'type'     => 'select',
                'title'    => esc_html__('Footer col 1', 'imate'), 
                'options'  => array(
                    '1' => 'Col 1',
                    '2' => 'Col 2',
                    '3' => 'Col 3',
                    '4' => 'Col 4',
                    '5' => 'Col 5',
                    '6' => 'Col 6',
                    '7' => 'Col 7',
                    '8' => 'Col 8',
                    '9' => 'Col 9',
                    '10' => 'Col 10',
                    '11' => 'Col 11',
                    '12' => 'Col 12',
                ),
                'default'  => '3',
            ),
            array(
                'id'       => 'footer_col_2',
                'type'     => 'select',
                'title'    => esc_html__('Footer col 2', 'imate'), 
                'options'  => array(
                    '1' => 'Col 1',
                    '2' => 'Col 2',
                    '3' => 'Col 3',
                    '4' => 'Col 4',
                    '5' => 'Col 5',
                    '6' => 'Col 6',
                    '7' => 'Col 7',
                    '8' => 'Col 8',
                    '9' => 'Col 9',
                    '10' => 'Col 10',
                    '11' => 'Col 11',
                    '12' => 'Col 12',
                ),
                'default'  => '3',
            ),
            array(
                'id'       => 'footer_col_3',
                'type'     => 'select',
                'title'    => esc_html__('Footer col 3', 'imate'), 
                'options'  => array(
                    '1' => 'Col 1',
                    '2' => 'Col 2',
                    '3' => 'Col 3',
                    '4' => 'Col 4',
                    '5' => 'Col 5',
                    '6' => 'Col 6',
                    '7' => 'Col 7',
                    '8' => 'Col 8',
                    '9' => 'Col 9',
                    '10' => 'Col 10',
                    '11' => 'Col 11',
                    '12' => 'Col 12',
                ),
                'default'  => '3',
            ),
            array(
                'id'       => 'footer_col_4',
                'type'     => 'select',
                'title'    => esc_html__('Footer col 4', 'imate'), 
                'options'  => array(
                    '1' => 'Col 1',
                    '2' => 'Col 2',
                    '3' => 'Col 3',
                    '4' => 'Col 4',
                    '5' => 'Col 5',
                    '6' => 'Col 6',
                    '7' => 'Col 7',
                    '8' => 'Col 8',
                    '9' => 'Col 9',
                    '10' => 'Col 10',
                    '11' => 'Col 11',
                    '12' => 'Col 12',
                ),
                'default'  => '3',
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( '404 Page', 'imate' ),
        'id'               => '404_page',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-exclamation-circle',
        'fields'     => array(
            array(
                'id'       => 'header_color_mode_404',
                'type'     => 'select',
                'title'    => esc_html__('Header color mode', 'imate'), 
                'options'  => array(
                    'default' => esc_html__('Default', 'imate'),
                    'light' => esc_html__('Light', 'imate'),
                    'dark' => esc_html__('Dark', 'imate'),
                ),
            ),
            array( 
                'id'       => '404_bg',
                'type'     => 'background',
                'title'    => esc_html__('Background image', 'imate'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array(
                'id'       => '404_page_sub_heading_color',
                'type'     => 'color',
                'title'    => esc_html__('Heading color', 'imate'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.banner-404 .sub-h'),
            ),
            array(
                'id'       => '404_page_heading_color',
                'type'     => 'color',
                'title'    => esc_html__('Heading color', 'imate'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.banner-404 .h'),
            ),
            array(
                'id'       => '404_sub_heading',
                'type'     => 'textarea',
                'title'    => esc_html__('Sub Heading', 'imate'),
                'default'  =>  __('Oooops...', 'imate'),
            ),
            array(
                'id'       => '404_heading',
                'type'     => 'textarea',
                'title'    => esc_html__('Heading', 'imate'),
                'default'  =>  __('404 Error... You are on<br>a non existing page!', 'imate'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Coming soon page', 'imate' ),
        'id'               => 'coming_soon',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-clock-o',
        'fields'     => array(
            array(
                'id'       => 'header_color_mode_coming_soon',
                'type'     => 'select',
                'title'    => esc_html__('Header color mode', 'imate'), 
                'options'  => array(
                    'default' => esc_html__('Default', 'imate'),
                    'light' => esc_html__('Light', 'imate'),
                    'dark' => esc_html__('Dark', 'imate'),
                ),
            ),
            array( 
                'id'       => 'coming_soon_bg',
                'type'     => 'background',
                'title'    => esc_html__('Background image', 'imate'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array(
                'id'       => 'coming_soon_color',
                'type'     => 'color',
                'title'    => esc_html__('Text color', 'imate'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.banner-coming-soon .banner .item'),
            ),
            array(
                'id'       => 'coming_soon_heading_color',
                'type'     => 'color',
                'title'    => esc_html__('Heading color', 'imate'),
                'validate' => 'color',
                'transparent' => false,
                'output'      => array('color' => '.banner-coming-soon .item h1.h'),
            ),
            array(
                'id'       => 'coming_soon_subscribe_code',
                'type'     => 'text',
                'title'    => esc_html__('Subscribe form code', 'imate'),
            ),
            array(
                'id'       => 'coming_soon_sub_heading',
                'type'     => 'textarea',
                'title'    => esc_html__('Sub Heading', 'imate'),
                'default'  => esc_html__('The website is under construction', 'imate'),
            ),
            array(
                'id'       => 'coming_soon_heading',
                'type'     => 'textarea',
                'title'    => esc_html__('Heading', 'imate'),
                'default'  => esc_html__('Coming Soon', 'imate'),
            ),
            array(
                'id'       => 'coming_soon_text',
                'type'     => 'textarea',
                'title'    => esc_html__('Text', 'imate'),
                'default'  => esc_html__('Subscribe to the newsletter to stay in the latest news', 'imate'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Project page', 'imate' ),
        'id'               => 'project_page',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-file-text',
        'fields'     => array(
            array(
                'id'       => 'project_header_color_mode',
                'type'     => 'select',
                'title'    => esc_html__('Header color mode', 'imate'), 
                'options'  => array(
                    'light' => esc_html__('Light', 'imate'),
                    'dark' => esc_html__('Dark', 'imate'),
                ),
                'std' => 'dark'
            ),
            array( 
                'id'       => 'project_top_background',
                'type'     => 'background',
                'title'    => esc_html__('Background of project page top', 'imate'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array(
                'id'       => 'project_top_heading',
                'type'     => 'textarea',
                'title'    => esc_html__('Project page top heading', 'imate'),
                'default'  => esc_html__('Gallery', 'imate'),
            ),
            array(
                'id'       => 'project_image',
                'type'     => 'select',
                'title'    => esc_html__('Project image', 'imate'), 
                'options'  => array(
                    'disable' => esc_html__('Disable', 'imate'),
                    'full' => esc_html__('Full', 'imate'),
                    'adaptive' => esc_html__('Adaptive', 'imate'),
                ),
                'default'  => 'full',
            ),
            array(
                'id'       => 'download-link',
                'type'     => 'select',
                'title'    => esc_html__('Download link on popup', 'imate'), 
                'options'  => array(
                    'yes' => esc_html__('Show', 'imate'),
                    'no' => esc_html__('Hide', 'imate'),
                ),
                'default'  => 'yes',
            ),
            array(
                'id'       => 'project_date',
                'type'     => 'select',
                'title'    => esc_html__('Show date', 'imate'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'imate'),
                    'hide' => esc_html__('Hide', 'imate'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'project_category',
                'type'     => 'select',
                'title'    => esc_html__('Show category', 'imate'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'imate'),
                    'hide' => esc_html__('Hide', 'imate'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'project_like',
                'type'     => 'select',
                'title'    => esc_html__('Show like', 'imate'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'imate'),
                    'hide' => esc_html__('Hide', 'imate'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'project_share',
                'type'     => 'select',
                'title'    => esc_html__('Show Share Links', 'imate'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'imate'),
                    'hide' => esc_html__('Hide', 'imate'),
                ),
                'default'  => 'show',
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Blog post', 'imate' ),
        'id'               => 'blog_post',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-wordpress',
        'fields'     => array(
            array(
                'id'       => 'blog_header_color_mode',
                'type'     => 'select',
                'title'    => esc_html__('Header color mode', 'imate'), 
                'options'  => array(
                    'light' => esc_html__('Light', 'imate'),
                    'dark' => esc_html__('Dark', 'imate'),
                ),
                'std' => 'dark'
            ),
            array( 
                'id'       => 'blog_top_background',
                'type'     => 'background',
                'title'    => esc_html__('Background of blog post top', 'imate'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
            array(
                'id'       => 'blog_top_heading',
                'type'     => 'textarea',
                'title'    => esc_html__('Blog post top heading', 'imate'),
                'default'  => esc_html__('Blog', 'imate'),
            ),
            array(
                'id'       => 'blog_feature_image',
                'type'     => 'select',
                'title'    => esc_html__('Blog feature image', 'imate'), 
                'options'  => array(
                    'hide' => esc_html__('Hide', 'imate'),
                    'show' => esc_html__('Show', 'imate'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'blog_date',
                'type'     => 'select',
                'title'    => esc_html__('Show date', 'imate'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'imate'),
                    'hide' => esc_html__('Hide', 'imate'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'blog_category',
                'type'     => 'select',
                'title'    => esc_html__('Show category', 'imate'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'imate'),
                    'hide' => esc_html__('Hide', 'imate'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'blog_like',
                'type'     => 'select',
                'title'    => esc_html__('Show like', 'imate'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'imate'),
                    'hide' => esc_html__('Hide', 'imate'),
                ),
                'default'  => 'show',
            ),
            array(
                'id'       => 'blog_share',
                'type'     => 'select',
                'title'    => esc_html__('Show Share Links', 'imate'), 
                'options'  => array(
                    'show' => esc_html__('Show', 'imate'),
                    'hide' => esc_html__('Hide', 'imate'),
                ),
                'default'  => 'show',
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Shop', 'imate' ),
        'id'               => 'shop_page',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-shopping-basket',
        'fields'     => array(
            array(
                'id'       => 'shop_header_color_mode',
                'type'     => 'select',
                'title'    => esc_html__('Header color mode', 'imate'), 
                'options'  => array(
                    'light' => esc_html__('Light', 'imate'),
                    'dark' => esc_html__('Dark', 'imate'),
                ),
                'std' => 'dark'
            ),
            array( 
                'id'       => 'shop_top_background',
                'type'     => 'background',
                'title'    => esc_html__('Background of blog post top', 'imate'),
                'background-attachment' => false,
                'background-position' => false,
                'background-repeat' => false,
                'background-origin' => false,
                'background-color' => false,
                'background-size' => false,
                'background-clip' => false,
                'preview_media' => true,
                'preview' => false,
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Google Maps API', 'imate' ),
        'id'               => 'google_maps_api',
        'customizer_width' => '400px',
        'icon'             => 'fa fa-map-pin',
        'fields'     => array(
            array(
                'id'       => 'google_maps_api_key',
                'type'     => 'text',
                'title'    => esc_html__('Google Map API Key', 'imate'), 
                'description' => __('Create an application in <a href="https://console.developers.google.com/flows/enableapi?apiid=places_backend,maps_backend,geocoding_backend,directions_backend,distance_matrix_backend,elevation_backend&keyType=CLIENT_SIDE&reusekey=true" target="_blank">Google Console</a> and add the Key here.', 'imate'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Site info', 'imate' ),
        'id'               => 'site_info',
        'customizer_width' => '400px',
        'icon'             => 'el el-info-circle',
        'fields'     => array(
            array(
                'id'       => 'opt-raw_info_4',
                'type'     => 'raw',
                'title'    => false,
                'content'  => $info_html,
            ),
        )
    ) );

    if(!function_exists('redux_register_custom_extension_loader')) :
        function redux_register_custom_extension_loader($ReduxFramework) {

            $extension_class = 'ReduxFramework_Extension_tlm';
            if ( ! class_exists( $extension_class ) ) {
                $class_file = dirname( __FILE__ ) . '/extensions/tlm/extension_tlm.php';
                $class_file = apply_filters( 'redux/extension/' . $ReduxFramework->args['opt_name'] . '/tlm', $class_file );
                if ( $class_file ) {
                    require_once( $class_file );
                }
            }
            if ( ! isset( $ReduxFramework->extensions[ 'tlm' ] ) ) {
                $ReduxFramework->extensions[ 'tlm' ] = new $extension_class( $ReduxFramework );
            }
        }

        add_action("redux/extensions/{$opt_name}/before", 'redux_register_custom_extension_loader', 0);
    endif;