<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 4.2
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

wc_print_notices();

do_action( 'woocommerce_before_cart' ); ?>

<div class="row">
	<form class="col-xs-12 col-md-8 col-lg-8" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">

	<?php do_action( 'woocommerce_before_cart_table' ); ?>

	<table class="shop_table shop_table_responsive cart" cellspacing="0">
		<thead>
			<tr>
				<th class="product-name"><span><span><?php esc_html_e( 'Product', 'imate' ); ?></span></span></th>
				<th class="product-price"><span><span><?php esc_html_e( 'Price', 'imate' ); ?></span></span></th>
				<th class="product-quantity"><span><span><?php esc_html_e( 'Quantity', 'imate' ); ?></span></span></th>
				<th class="product-subtotal"><span><span><?php esc_html_e( 'Total', 'imate' ); ?></span></span></th>
			</tr>
		</thead>
		<tbody>
			<?php do_action( 'woocommerce_before_cart_contents' ); ?>

			<?php
			foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
				$_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
				$product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

				if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
					$product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
					?>
					<tr class="<?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">

						<td class="product-name" data-title="<?php esc_attr_e( 'Product', 'imate' ); ?>">
							<?php
								echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
									'<a href="%s" class="remove" title="%s" data-product_id="%s" data-product_sku="%s"></a>',
									esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
									__( 'Remove this item', 'imate' ),
									esc_attr( $product_id ),
									esc_attr( $_product->get_sku() )
								), $cart_item_key );

								$thumbnail = wp_get_attachment_image_src(get_post_thumbnail_id($_product->get_ID()), 'medium')[0];

								if ( ! $product_permalink ) {
									echo wp_kses($thumbnail, 'post');
								} else {
									printf( '<a href="%s" class="image" style="background-image: url(%s)"></a>', esc_url( $product_permalink ), $thumbnail );
								}
							?>
							<div class="h">
								<div class="cell">
									<?php
										if ( ! $product_permalink ) {
											echo apply_filters( 'woocommerce_cart_item_name', $_product->get_title(), $cart_item, $cart_item_key ) . '&nbsp;';
										} else {
											echo apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s" class="name">%s</a>', esc_url( $product_permalink ), $_product->get_title() ), $cart_item, $cart_item_key );
										}

										// Meta data
										echo wc_get_formatted_cart_item_data( $cart_item );

										// Backorder notification
										if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
											echo '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'imate' ) . '</p>';
										}

										if(function_exists('get_field') && (!empty(get_field('event_date', $_product->get_id()) || !empty(get_field('event_location', $_product->get_id()))))) { ?>
											<span class="details">
												<?php if(!empty(get_field('event_date', $_product->get_id()))) {
													$date = mysql2date('M d', get_field('event_date', $_product->get_id()));
												?>
													<span class="d"><i class="material-design-icon-history-clock-button"></i><span><?php echo strip_tags($date) ?></span></span>
												<?php } if(!empty(get_field('event_location', $_product->get_id()))) { ?>
													<span class="d"><i class="material-design-icon-map-placeholder"></i><span><?php echo strip_tags(get_field('event_location', $_product->get_id())) ?></span></span>
												<?php } ?>
											</span>
										<?php }
									?>
								</div>
							</div>
						</td>

						<td class="product-price" data-title="<?php esc_attr_e( 'Price', 'imate' ); ?>">
							<?php
								echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
							?>
						</td>

						<td class="product-quantity" data-title="<?php esc_attr_e( 'Quantity', 'imate' ); ?>">
							<?php
								if ( $_product->is_sold_individually() ) {
									$product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
								} else {
									$product_quantity = woocommerce_quantity_input( array(
										'input_name'  => "cart[{$cart_item_key}][qty]",
										'input_value' => $cart_item['quantity'],
										'max_value'   => $_product->backorders_allowed() ? '' : $_product->get_stock_quantity(),
										'min_value'   => '0'
									), $_product, false );
								}

								echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item );
							?>
						</td>

						<td class="product-subtotal" data-title="<?php esc_attr_e( 'Total', 'imate' ); ?>">
							<?php
								echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key );
							?>
						</td>
					</tr>
					<?php
				}
			}

			do_action( 'woocommerce_cart_contents' );
			?>
			<tr>
				<td colspan="6" class="actions">
					<?php if ( wc_coupons_enabled() ) { ?>
						<div class="coupon-area">

							<input type="text" name="coupon_code" class="style1 input-text" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'imate' ); ?>" /> <input type="submit" class="button-style4" name="apply_coupon" value="<?php esc_attr_e( 'Apply Coupon', 'imate' ); ?>" />

							<?php do_action( 'woocommerce_cart_coupon' ); ?>
						</div>
					<?php } ?>
					

					<input type="submit" class="button-style2" name="update_cart" value="<?php esc_attr_e( 'Update Cart', 'imate' ); ?>" />

					<?php do_action( 'woocommerce_cart_actions' ); ?>

					<?php wp_nonce_field( 'woocommerce-cart' ); ?>
				</td>
			</tr>

			<?php do_action( 'woocommerce_after_cart_contents' ); ?>
		</tbody>
	</table>

	<?php do_action( 'woocommerce_after_cart_table' ); ?>

	</form>

	<div class="col-xs-12 col-xs-12 col-md-4 col-lg-4">
		<div class="cart-collaterals tac">
			<?php do_action( 'woocommerce_cart_collaterals' ); ?>
		</div>
	</div>

</div>

<?php do_action( 'woocommerce_after_cart' ); ?>
